@@ -15,8 +15,7 @@
 extern "C" {
 
 // to be called from other languages, hidden from the public apis
-adios2_adios *adios2_init_config_glue_mpi(const char *config_file,
-                                          MPI_Comm comm,
+adios2_adios *adios2_init_config_glue_mpi(const char *config_file, MPI_Comm comm,
                                           const char *host_language)
 {
     adios2_adios *adios = nullptr;
@@ -24,10 +23,9 @@ adios2_adios *adios2_init_config_glue_mpi(const char *config_file,
     try
     {
         adios2::helper::CheckForNullptr(
-            config_file,
-            "for config_file, in call to adios2_init or adios2_init_config");
-        adios = reinterpret_cast<adios2_adios *>(new adios2::core::ADIOS(
-            config_file, adios2::helper::CommDupMPI(comm), host_language));
+            config_file, "for config_file, in call to adios2_init or adios2_init_config");
+        adios = reinterpret_cast<adios2_adios *>(
+            new adios2::core::ADIOS(config_file, adios2::helper::CommDupMPI(comm), host_language));
     }
     catch (...)
     {
@@ -36,10 +34,7 @@ adios2_adios *adios2_init_config_glue_mpi(const char *config_file,
     return adios;
 }
 
-adios2_adios *adios2_init_mpi(MPI_Comm comm)
-{
-    return adios2_init_config_glue_mpi("", comm, "C");
-}
+adios2_adios *adios2_init_mpi(MPI_Comm comm) { return adios2_init_config_glue_mpi("", comm, "C"); }
 
 adios2_adios *adios2_init_config_mpi(const char *config_file, MPI_Comm comm)
 {
