@@ -19,11 +19,9 @@ namespace py11
 
 Engine IO::Open(const std::string &name, const int mode, MPI4PY_Comm comm)
 {
-    helper::CheckForNullptr(m_IO,
-                            "for engine " + name + ", in call to IO::Open");
+    helper::CheckForNullptr(m_IO, "for engine " + name + ", in call to IO::Open");
 
-    return Engine(&m_IO->Open(name, static_cast<adios2::Mode>(mode),
-                              helper::CommDupMPI(comm)));
+    return Engine(&m_IO->Open(name, static_cast<adios2::Mode>(mode), helper::CommDupMPI(comm)));
 }
 
 } // end namespace py11
