@@ -22,10 +22,8 @@
 #include "adios2/engine/bp3/BP3Writer.h"
 #include "adios2/engine/bp4/BP4Reader.h"
 #include "adios2/engine/bp4/BP4Writer.h"
-#ifdef ADIOS2_HAVE_BP5
 #include "adios2/engine/bp5/BP5Reader.h"
 #include "adios2/engine/bp5/BP5Writer.h"
-#endif
 #include "adios2/engine/inline/InlineReader.h"
 #include "adios2/engine/inline/InlineWriter.h"
 #include "adios2/engine/mhs/MhsReader.h"
@@ -51,6 +49,15 @@
 #include "adios2/engine/sst/SstWriter.h"
 #endif
 
+#ifdef ADIOS2_HAVE_DAOS // external dependencies
+#include "adios2/engine/daos/DaosReader.h"
+#include "adios2/engine/daos/DaosWriter.h"
+#endif
+
+#ifdef ADIOS2_HAVE_CAMPAIGN // external dependencies
+#include "adios2/engine/campaign/CampaignReader.h"
+#endif
+
 namespace adios2
 {
 namespace core
@@ -61,22 +68,12 @@ IO::EngineFactoryEntry IO_MakeEngine_HDF5();
 namespace
 {
 std::unordered_map<std::string, IO::EngineFactoryEntry> Factory = {
-    {"bp3",
-     {IO::MakeEngine<engine::BP3Reader>, IO::MakeEngine<engine::BP3Writer>}},
-    {"bp4",
-     {IO::MakeEngine<engine::BP4Reader>, IO::MakeEngine<engine::BP4Writer>}},
-    {"bp5",
-#ifdef ADIOS2_HAVE_BP5
-     {IO::MakeEngine<engine::BP5Reader>, IO::MakeEngine<engine::BP5Writer>}
-#else
-     IO::NoEngineEntry("ERROR: this version didn't compile with "
-                       "BP5 library, can't use BP5 engine\n")
-#endif
-    },
+    {"bp3", {IO::MakeEngine<engine::BP3Reader>, IO::MakeEngine<engine::BP3Writer>}},
+    {"bp4", {IO::MakeEngine<engine::BP4Reader>, IO::MakeEngine<engine::BP4Writer>}},
+    {"bp5", {IO::MakeEngine<engine::BP5Reader>, IO::MakeEngine<engine::BP5Writer>}},
     {"dataman",
 #ifdef ADIOS2_HAVE_DATAMAN
-     {IO::MakeEngine<engine::DataManReader>,
-      IO::MakeEngine<engine::DataManWriter>}
+     {IO::MakeEngine<engine::DataManReader>, IO::MakeEngine<engine::DataManWriter>}
 #else
      IO::NoEngineEntry("ERROR: this version didn't compile with "
                        "DataMan library, can't use DataMan engine\n")
@@ -98,6 +95,14 @@ std::unordered_map<std::string, IO::EngineFactoryEntry> Factory = {
 #else
      IO::NoEngineEntry("ERROR: this version didn't compile with "
                        "Sst library, can't use Sst engine\n")
+#endif
+    },
+    {"daos",
+#ifdef ADIOS2_HAVE_DAOS
+     {IO::MakeEngine<engine::DaosReader>, IO::MakeEngine<engine::DaosWriter>}
+#else
+     IO::NoEngineEntry("ERROR: this version didn't compile with "
+                       "DAOS library, can't use DAOS engine\n")
 #endif
     },
     {"effis",
@@ -108,9 +113,8 @@ std::unordered_map<std::string, IO::EngineFactoryEntry> Factory = {
                        "Sst library, can't use Sst engine\n")
 #endif
     },
-    {"dataspaces",
-     IO::NoEngineEntry("ERROR: this version didn't compile with "
-                       "DataSpaces library, can't use DataSpaces engine\n")},
+    {"dataspaces", IO::NoEngineEntry("ERROR: this version didn't compile with "
+                                     "DataSpaces library, can't use DataSpaces engine\n")},
     {"hdf5",
 #ifdef ADIOS2_HAVE_HDF5
      IO_MakeEngine_HDF5()
@@ -119,20 +123,31 @@ std::unordered_map<std::string, IO::EngineFactoryEntry> Factory = {
                        "HDF5 library, can't use HDF5 engine\n")
 #endif
     },
-    {"skeleton",
-     {IO::MakeEngine<engine::SkeletonReader>,
-      IO::MakeEngine<engine::SkeletonWriter>}},
-    {"inline",
-     {IO::MakeEngine<engine::InlineReader>,
-      IO::MakeEngine<engine::InlineWriter>}},
-    {"null",
-     {IO::MakeEngine<engine::NullReader>, IO::MakeEngine<engine::NullWriter>}},
+    {"skeleton", {IO::MakeEngine<engine::SkeletonReader>, IO::MakeEngine<engine::SkeletonWriter>}},
+    {"inline", {IO::MakeEngine<engine::InlineReader>, IO::MakeEngine<engine::InlineWriter>}},
+    {"null", {IO::MakeEngine<engine::NullReader>, IO::MakeEngine<engine::NullWriter>}},
     {"nullcore",
      {IO::NoEngine("ERROR: nullcore engine does not support read mode"),
       IO::MakeEngine<engine::NullWriter>}},
-    {"plugin",
-     {IO::MakeEngine<plugin::PluginEngine>,
-      IO::MakeEngine<plugin::PluginEngine>}},
+    {"plugin", {IO::MakeEngine<plugin::PluginEngine>, IO::MakeEngine<plugin::PluginEngine>}},
+
+    {"campaign",
+#ifdef ADIOS2_HAVE_CAMPAIGN
+     {IO::MakeEngine<engine::CampaignReader>,
+      IO::NoEngine("ERROR: campaign engine does not support write mode")}
+#else
+     IO::NoEngineEntry("ERROR: this version didn't compile with "
+                       "support for campaign management, can't use Campaign engine\n")
+#endif
+    },
+};
+
+const std::unordered_map<std::string, bool> ReadRandomAccess_Supported = {
+    {"bp3", false},     {"bp4", false},        {"bp5", true},      {"dataman", false},
+    {"ssc", false},     {"mhs", false},        {"sst", false},     {"daos", false},
+    {"effis", false},   {"dataspaces", false}, {"hdf5", false},    {"skeleton", true},
+    {"inline", false},  {"null", true},        {"nullcore", true}, {"plugin", false},
+    {"campaign", true},
 };
 
 // Synchronize access to the factory in case one thread is
@@ -149,8 +164,7 @@ FactoryLookup(std::string const &name)
 
 struct ThrowError
 {
-    std::shared_ptr<Engine> operator()(IO &, const std::string &, const Mode,
-                                       helper::Comm) const
+    std::shared_ptr<Engine> operator()(IO &, const std::string &, const Mode, helper::Comm) const
     {
         helper::Throw<std::invalid_argument>("Core", "IO", "Operator", Err);
         return nullptr;
@@ -162,10 +176,7 @@ struct ThrowError
 
 IO::MakeEngineFunc IO::NoEngine(std::string e) { return ThrowError{e}; }
 
-IO::EngineFactoryEntry IO::NoEngineEntry(std::string e)
-{
-    return {NoEngine(e), NoEngine(e)};
-}
+IO::EngineFactoryEntry IO::NoEngineEntry(std::string e) { return {NoEngine(e), NoEngine(e)}; }
 
 void IO::RegisterEngine(const std::string &engineType, EngineFactoryEntry entry)
 {
@@ -175,8 +186,7 @@ void IO::RegisterEngine(const std::string &engineType, EngineFactoryEntry entry)
 
 IO::IO(ADIOS &adios, const std::string name, const bool inConfigFile,
        const std::string hostLanguage)
-: m_ADIOS(adios), m_Name(name), m_HostLanguage(hostLanguage),
-  m_InConfigFile(inConfigFile)
+: m_ADIOS(adios), m_Name(name), m_HostLanguage(hostLanguage), m_InConfigFile(inConfigFile)
 {
 }
 
@@ -184,16 +194,14 @@ IO::~IO() = default;
 
 void IO::SetEngine(const std::string engineType) noexcept
 {
-    auto lf_InsertParam = [&](const std::string &key,
-                              const std::string &value) {
+    auto lf_InsertParam = [&](const std::string &key, const std::string &value) {
         m_Parameters.insert(std::pair<std::string, std::string>(key, value));
     };
 
     /* First step in handling virtual engine names */
     std::string finalEngineType;
     std::string engineTypeLC = engineType;
-    std::transform(engineTypeLC.begin(), engineTypeLC.end(),
-                   engineTypeLC.begin(), ::tolower);
+    std::transform(engineTypeLC.begin(), engineTypeLC.end(), engineTypeLC.begin(), ::tolower);
     if (engineTypeLC == "insituviz" || engineTypeLC == "insituvisualization")
     {
         finalEngineType = "SST";
@@ -249,8 +257,7 @@ void IO::SetParameters(const Params &parameters) noexcept
 void IO::SetParameters(const std::string &parameters)
 {
     PERFSTUBS_SCOPED_TIMER("IO::other");
-    adios2::Params parameterMap =
-        adios2::helper::BuildParametersMap(parameters, '=', ',');
+    adios2::Params parameterMap = adios2::helper::BuildParametersMap(parameters, '=', ',');
     SetParameters(parameterMap);
 }
 
@@ -273,8 +280,7 @@ size_t IO::AddTransport(const std::string type, const Params &parameters)
     PERFSTUBS_SCOPED_TIMER("IO::other");
     Params parametersMap(parameters);
 
-    if (parameters.count("transport") == 1 ||
-        parameters.count("Transport") == 1)
+    if (parameters.count("transport") == 1 || parameters.count("Transport") == 1)
     {
         helper::Throw<std::invalid_argument>(
             "Core", "IO", "AddTransport",
@@ -289,22 +295,24 @@ size_t IO::AddTransport(const std::string type, const Params &parameters)
     return m_TransportsParameters.size() - 1;
 }
 
-void IO::SetTransportParameter(const size_t transportIndex,
-                               const std::string key, const std::string value)
+void IO::SetTransportParameter(const size_t transportIndex, const std::string key,
+                               const std::string value)
 {
     PERFSTUBS_SCOPED_TIMER("IO::other");
     if (transportIndex >= m_TransportsParameters.size())
     {
-        helper::Throw<std::invalid_argument>(
-            "Core", "IO", "SetTransportParameter",
-            "transport Index " + std::to_string(transportIndex) +
-                " does not exist");
+        helper::Throw<std::invalid_argument>("Core", "IO", "SetTransportParameter",
+                                             "transport Index " + std::to_string(transportIndex) +
+                                                 " does not exist");
     }
 
     m_TransportsParameters[transportIndex][key] = value;
 }
 
 const VarMap &IO::GetVariables() const noexcept { return m_Variables; }
+#ifdef ADIOS2_HAVE_DERIVED_VARIABLE
+const VarMap &IO::GetDerivedVariables() const noexcept { return m_VariablesDerived; }
+#endif
 
 const AttrMap &IO::GetAttributes() const noexcept { return m_Attributes; }
 
@@ -378,8 +386,7 @@ void IO::RemoveAllAttributes() noexcept
     m_Attributes.clear();
 }
 
-std::map<std::string, Params>
-IO::GetAvailableVariables(const std::set<std::string> &keys) noexcept
+std::map<std::string, Params> IO::GetAvailableVariables(const std::set<std::string> &keys) noexcept
 {
     PERFSTUBS_SCOPED_TIMER("IO::GetAvailableVariables");
 
@@ -392,10 +399,10 @@ IO::GetAvailableVariables(const std::set<std::string> &keys) noexcept
         if (type == DataType::Struct)
         {
         }
-#define declare_template_instantiation(T)                                      \
-    else if (type == helper::GetDataType<T>())                                 \
-    {                                                                          \
-        variablesInfo[variableName] = GetVariableInfo<T>(variableName, keys);  \
+#define declare_template_instantiation(T)                                                          \
+    else if (type == helper::GetDataType<T>())                                                     \
+    {                                                                                              \
+        variablesInfo[variableName] = GetVariableInfo<T>(variableName, keys);                      \
     }
         ADIOS2_FOREACH_STDTYPE_1ARG(declare_template_instantiation)
 #undef declare_template_instantiation
@@ -404,10 +411,9 @@ IO::GetAvailableVariables(const std::set<std::string> &keys) noexcept
     return variablesInfo;
 }
 
-std::map<std::string, Params>
-IO::GetAvailableAttributes(const std::string &variableName,
-                           const std::string separator,
-                           const bool fullNameKeys) noexcept
+std::map<std::string, Params> IO::GetAvailableAttributes(const std::string &variableName,
+                                                         const std::string separator,
+                                                         const bool fullNameKeys) noexcept
 {
     PERFSTUBS_SCOPED_TIMER("IO::GetAvailableAttributes");
     std::map<std::string, Params> attributesInfo;
@@ -422,8 +428,7 @@ IO::GetAvailableAttributes(const std::string &variableName,
         }
         else
         {
-            attributesInfo = itVariable->second->GetAttributesInfo(
-                *this, separator, fullNameKeys);
+            attributesInfo = itVariable->second->GetAttributesInfo(*this, separator, fullNameKeys);
         }
         return attributesInfo;
     }
@@ -451,8 +456,7 @@ DataType IO::InquireVariableType(const std::string &name) const noexcept
     return InquireVariableType(itVariable);
 }
 
-DataType IO::InquireVariableType(const VarMap::const_iterator itVariable) const
-    noexcept
+DataType IO::InquireVariableType(const VarMap::const_iterator itVariable) const noexcept
 {
     if (itVariable == m_Variables.end())
     {
@@ -478,13 +482,11 @@ DataType IO::InquireVariableType(const VarMap::const_iterator itVariable) const
     return type;
 }
 
-DataType IO::InquireAttributeType(const std::string &name,
-                                  const std::string &variableName,
+DataType IO::InquireAttributeType(const std::string &name, const std::string &variableName,
                                   const std::string separator) const noexcept
 {
     PERFSTUBS_SCOPED_TIMER("IO::other");
-    const std::string globalName =
-        helper::GlobalName(name, variableName, separator);
+    const std::string globalName = helper::GlobalName(name, variableName, separator);
 
     auto itAttribute = m_Attributes.find(globalName);
     if (itAttribute == m_Attributes.end())
@@ -495,8 +497,7 @@ DataType IO::InquireAttributeType(const std::string &name,
     return itAttribute->second->m_Type;
 }
 
-void IO::AddOperation(const std::string &variable,
-                      const std::string &operatorType,
+void IO::AddOperation(const std::string &variable, const std::string &operatorType,
                       const Params &parameters) noexcept
 {
     PERFSTUBS_SCOPED_TIMER("IO::other");
@@ -523,8 +524,8 @@ Engine &IO::Open(const std::string &name, const Mode mode, helper::Comm comm)
     {
         if (isEngineActive) // check if active
         {
-            helper::Throw<std::invalid_argument>(
-                "Core", "IO", "Open", "Engine " + name + " is opened twice");
+            helper::Throw<std::invalid_argument>("Core", "IO", "Open",
+                                                 "Engine " + name + " is opened twice");
         }
     }
 
@@ -541,23 +542,25 @@ Engine &IO::Open(const std::string &name, const Mode mode, helper::Comm comm)
     std::string engineTypeLC = m_EngineType;
     if (!isDefaultEngine)
     {
-        std::transform(engineTypeLC.begin(), engineTypeLC.end(),
-                       engineTypeLC.begin(), ::tolower);
+        std::transform(engineTypeLC.begin(), engineTypeLC.end(), engineTypeLC.begin(), ::tolower);
     }
 
     /* Second step in handling virtual engines */
     /* BPFile for read needs to use BP5, BP4, or BP3 depending on the file's
      * version
      */
-    if ((engineTypeLC == "file" || engineTypeLC == "bpfile" ||
-         engineTypeLC == "bp" || isDefaultEngine))
+    if ((engineTypeLC == "file" || engineTypeLC == "bpfile" || engineTypeLC == "bp" ||
+         isDefaultEngine))
     {
         if (helper::EndsWith(name, ".h5", false))
         {
             engineTypeLC = "hdf5";
         }
-        else if ((mode_to_use == Mode::Read) ||
-                 (mode_to_use == Mode::ReadRandomAccess))
+        else if (helper::EndsWith(name, ".aca", false))
+        {
+            engineTypeLC = "campaign";
+        }
+        else if ((mode_to_use == Mode::Read) || (mode_to_use == Mode::ReadRandomAccess))
         {
             if (adios2sys::SystemTools::FileIsDirectory(name))
             {
@@ -580,8 +583,7 @@ Engine &IO::Open(const std::string &name, const Mode mode, helper::Comm comm)
                     /* We need to figure out the type of file
                      * from the file itself
                      */
-                    if (helper::IsHDF5File(name, *this, comm,
-                                           m_TransportsParameters))
+                    if (helper::IsHDF5File(name, *this, comm, m_TransportsParameters))
                     {
                         engineTypeLC = "hdf5";
                     }
@@ -594,13 +596,8 @@ Engine &IO::Open(const std::string &name, const Mode mode, helper::Comm comm)
         }
         else
         {
-#ifdef ADIOS2_HAVE_BP5
             // File default for writing: BP5
             engineTypeLC = "bp5";
-#else
-            // File default for writing: BP4
-            engineTypeLC = "bp4";
-#endif
         }
     }
 
@@ -616,34 +613,26 @@ Engine &IO::Open(const std::string &name, const Mode mode, helper::Comm comm)
         //          << std::endl;
     }
 
-    if ((engineTypeLC != "bp5") && (mode_to_use == Mode::ReadRandomAccess))
-    {
-        // only BP5 special-cases file-reader random access mode
-        mode_to_use = Mode::Read;
-    }
     // For the inline engine, there must be exactly 1 reader, and exactly 1
     // writer.
     if (engineTypeLC == "inline")
     {
         if (mode_to_use == Mode::Append)
         {
-            helper::Throw<std::runtime_error>(
-                "Core", "IO", "Open",
-                "Append mode is not supported in the inline engine.");
+            helper::Throw<std::runtime_error>("Core", "IO", "Open",
+                                              "Append mode is not supported in the inline engine.");
         }
 
         // See inline.rst:44
         if (mode_to_use == Mode::Sync)
         {
-            helper::Throw<std::runtime_error>(
-                "Core", "IO", "Open",
-                "Sync mode is not supported in the inline engine.");
+            helper::Throw<std::runtime_error>("Core", "IO", "Open",
+                                              "Sync mode is not supported in the inline engine.");
         }
 
         if (m_Engines.size() >= 2)
         {
-            std::string msg =
-                "Failed to add engine " + name + " to IO \'" + m_Name + "\'. ";
+            std::string msg = "Failed to add engine " + name + " to IO \'" + m_Name + "\'. ";
             msg += "An inline engine must have exactly one writer, and one "
                    "reader. ";
             msg += "There are already two engines declared, so no more can be "
@@ -657,10 +646,8 @@ Engine &IO::Open(const std::string &name, const Mode mode, helper::Comm comm)
             auto engine_ptr = m_Engines.begin()->second;
             if (engine_ptr->OpenMode() == mode_to_use)
             {
-                std::string msg =
-                    "The previously added engine " + engine_ptr->m_Name +
-                    " is already opened in same mode requested for " + name +
-                    ". ";
+                std::string msg = "The previously added engine " + engine_ptr->m_Name +
+                                  " is already opened in same mode requested for " + name + ". ";
                 msg += "The inline engine requires exactly one writer and one "
                        "reader.";
                 helper::Throw<std::runtime_error>("Core", "IO", "Open", msg);
@@ -668,34 +655,43 @@ Engine &IO::Open(const std::string &name, const Mode mode, helper::Comm comm)
         }
     }
 
+    if (mode_to_use == Mode::ReadRandomAccess)
+    {
+        // older engines don't know about ReadRandomAccess Mode
+        auto it = ReadRandomAccess_Supported.find(engineTypeLC);
+        if (it != ReadRandomAccess_Supported.end())
+        {
+            if (!it->second)
+            {
+                mode_to_use = Mode::Read;
+            }
+        }
+    }
+
     auto f = FactoryLookup(engineTypeLC);
     if (f != Factory.end())
     {
-        if ((mode_to_use == Mode::Read) ||
-            (mode_to_use == Mode::ReadRandomAccess))
+        if ((mode_to_use == Mode::Read) || (mode_to_use == Mode::ReadRandomAccess))
         {
-            engine =
-                f->second.MakeReader(*this, name, mode_to_use, std::move(comm));
+            engine = f->second.MakeReader(*this, name, mode_to_use, std::move(comm));
         }
         else
         {
-            engine =
-                f->second.MakeWriter(*this, name, mode_to_use, std::move(comm));
+            engine = f->second.MakeWriter(*this, name, mode_to_use, std::move(comm));
         }
     }
     else
     {
         helper::Throw<std::invalid_argument>("Core", "IO", "Open",
-                                             "Engine type " + m_EngineType +
-                                                 " is not valid");
+                                             "Engine type " + m_EngineType + " is not valid");
     }
 
     auto itEngine = m_Engines.emplace(name, std::move(engine));
 
     if (!itEngine.second)
     {
-        helper::Throw<std::invalid_argument>(
-            "Core", "IO", "Open", "failed to create Engine " + m_EngineType);
+        helper::Throw<std::invalid_argument>("Core", "IO", "Open",
+                                             "failed to create Engine " + m_EngineType);
     }
     // return a reference
     return *itEngine.first->second.get();
@@ -770,12 +766,10 @@ void IO::FlushAll()
     }
 }
 
-void IO::ResetVariablesStepSelection(const bool zeroStart,
-                                     const std::string hint)
+void IO::ResetVariablesStepSelection(const bool zeroStart, const std::string hint)
 {
     PERFSTUBS_SCOPED_TIMER("IO::other");
-    for (auto itVariable = m_Variables.begin(); itVariable != m_Variables.end();
-         ++itVariable)
+    for (auto itVariable = m_Variables.begin(); itVariable != m_Variables.end(); ++itVariable)
     {
         const DataType type = InquireVariableType(itVariable);
 
@@ -802,13 +796,11 @@ void IO::SetPrefixedNames(const bool isStep) noexcept
     const std::set<std::string> attributes = helper::KeysToSet(m_Attributes);
     const std::set<std::string> variables = helper::KeysToSet(m_Variables);
 
-    for (auto itVariable = m_Variables.begin(); itVariable != m_Variables.end();
-         ++itVariable)
+    for (auto itVariable = m_Variables.begin(); itVariable != m_Variables.end(); ++itVariable)
     {
         // if for each step (BP4), check if variable type is not empty
         // (means variable exist in that step)
-        const DataType type = isStep ? InquireVariableType(itVariable)
-                                     : itVariable->second->m_Type;
+        const DataType type = isStep ? InquireVariableType(itVariable) : itVariable->second->m_Type;
 
         if (type == DataType::None)
         {
@@ -821,10 +813,8 @@ void IO::SetPrefixedNames(const bool isStep) noexcept
         else
         {
             VariableBase &variable = *itVariable->second;
-            variable.m_PrefixedVariables =
-                helper::PrefixMatches(variable.m_Name, variables);
-            variable.m_PrefixedAttributes =
-                helper::PrefixMatches(variable.m_Name, attributes);
+            variable.m_PrefixedVariables = helper::PrefixMatches(variable.m_Name, variables);
+            variable.m_PrefixedAttributes = helper::PrefixMatches(variable.m_Name, attributes);
         }
     }
 
@@ -837,10 +827,9 @@ void IO::CheckAttributeCommon(const std::string &name) const
     auto itAttribute = m_Attributes.find(name);
     if (itAttribute != m_Attributes.end())
     {
-        helper::Throw<std::invalid_argument>(
-            "Core", "IO", "CheckAttributeCommon",
-            "Attribute " + name + " exists in IO " + m_Name +
-                ", in call to DefineAttribute");
+        helper::Throw<std::invalid_argument>("Core", "IO", "CheckAttributeCommon",
+                                             "Attribute " + name + " exists in IO " + m_Name +
+                                                 ", in call to DefineAttribute");
     }
 }
 
@@ -856,17 +845,99 @@ void IO::CheckTransportType(const std::string type) const
     }
 }
 
+#ifdef ADIOS2_HAVE_DERIVED_VARIABLE
+VariableDerived &IO::DefineDerivedVariable(const std::string &name, const std::string &exp_string,
+                                           const DerivedVarType varType)
+{
+    PERFSTUBS_SCOPED_TIMER("IO::DefineDerivedVariable");
+
+    {
+        auto itVariable = m_VariablesDerived.find(name);
+        if (itVariable != m_VariablesDerived.end())
+        {
+            helper::Throw<std::invalid_argument>("Core", "IO", "DefineDerivedVariable",
+                                                 "derived variable " + name +
+                                                     " already defined in IO " + m_Name);
+        }
+        else
+        {
+            auto itVariable = m_Variables.find(name);
+            if (itVariable != m_Variables.end())
+            {
+                helper::Throw<std::invalid_argument>(
+                    "Core", "IO", "DefineDerivedVariable",
+                    "derived variable " + name +
+                        " trying to use an already defined variable name in IO " + m_Name);
+            }
+        }
+    }
+
+    derived::Expression derived_exp(exp_string);
+    std::vector<std::string> var_list = derived_exp.VariableNameList();
+    DataType expressionType = DataType::None;
+    bool isConstant = true;
+    std::map<std::string, std::tuple<Dims, Dims, Dims>> name_to_dims;
+    // check correctness for the variable names and types within the expression
+    for (auto var_name : var_list)
+    {
+        auto itVariable = m_Variables.find(var_name);
+        if (itVariable == m_Variables.end())
+            helper::Throw<std::invalid_argument>("Core", "IO", "DefineDerivedVariable",
+                                                 "using undefine variable " + var_name +
+                                                     " in defining the derived variable " + name);
+        DataType var_type = InquireVariableType(var_name);
+        if (expressionType == DataType::None)
+            expressionType = var_type;
+        if (expressionType != var_type)
+            helper::Throw<std::invalid_argument>("Core", "IO", "DefineDerivedVariable",
+                                                 "all variables within a derived variable "
+                                                 " must have the same type ");
+        if ((itVariable->second)->IsConstantDims() == false)
+            isConstant = false;
+        name_to_dims.insert({var_name,
+                             {(itVariable->second)->m_Start, (itVariable->second)->m_Count,
+                              (itVariable->second)->m_Shape}});
+    }
+    // std::cout << "Derived variable " << name << ": PASS : variables exist and have the same type"
+    //          << std::endl;
+    // set the initial shape of the expression and check correcness
+    derived_exp.SetDims(name_to_dims);
+    // std::cout << "Derived variable " << name << ": PASS : initial variable dimensions are valid"
+    //          << std::endl;
+
+    // create derived variable with the expression
+    auto itVariablePair = m_VariablesDerived.emplace(
+        name, std::unique_ptr<VariableBase>(
+                  new VariableDerived(name, derived_exp, expressionType, isConstant, varType)));
+    VariableDerived &variable = static_cast<VariableDerived &>(*itVariablePair.first->second);
+
+    // check IO placeholder for variable operations
+    auto itOperations = m_VarOpsPlaceholder.find(name);
+    if (itOperations != m_VarOpsPlaceholder.end())
+    {
+        // allow to apply an operation only for derived variables that save the data
+        if (varType != DerivedVarType::StoreData)
+            helper::Throw<std::invalid_argument>(
+                "Core", "IO", "DefineDerivedVariable",
+                "Operators for derived variables can only be applied "
+                " for DerivedVarType::StoreData types.");
+        variable.m_Operations.reserve(itOperations->second.size());
+        for (auto &operation : itOperations->second)
+        {
+            variable.AddOperation(operation.first, operation.second);
+        }
+    }
+    return variable;
+}
+#endif
+
 StructDefinition &IO::DefineStruct(const std::string &name, const size_t size)
 {
-    return m_ADIOS.m_StructDefinitions
-        .emplace(name, StructDefinition(name, size))
-        ->second;
+    return m_ADIOS.m_StructDefinitions.emplace(name, StructDefinition(name, size))->second;
 }
 
-VariableStruct &IO::DefineStructVariable(const std::string &name,
-                                         StructDefinition &def,
-                                         const Dims &shape, const Dims &start,
-                                         const Dims &count,
+VariableStruct &IO::DefineStructVariable(const std::string &name, StructDefinition &def,
+                                         const Dims &shape, const Dims &start, const Dims &count,
                                          const bool constantDims)
 {
 
@@ -876,18 +947,17 @@ VariableStruct &IO::DefineStructVariable(const std::string &name,
         auto itVariable = m_Variables.find(name);
         if (itVariable != m_Variables.end())
         {
-            helper::Throw<std::invalid_argument>(
-                "Core", "IO", "DefineStructVariable",
-                "variable " + name + " already defined in IO " + m_Name);
+            helper::Throw<std::invalid_argument>("Core", "IO", "DefineStructVariable",
+                                                 "variable " + name + " already defined in IO " +
+                                                     m_Name);
         }
     }
 
-    auto itVariablePair = m_Variables.emplace(
-        name, std::unique_ptr<VariableBase>(new VariableStruct(
-                  name, def, shape, start, count, constantDims)));
+    auto itVariablePair =
+        m_Variables.emplace(name, std::unique_ptr<VariableBase>(new VariableStruct(
+                                      name, def, shape, start, count, constantDims)));
 
-    VariableStruct &variable =
-        static_cast<VariableStruct &>(*itVariablePair.first->second);
+    VariableStruct &variable = static_cast<VariableStruct &>(*itVariablePair.first->second);
 
     // check IO placeholder for variable operations
     auto itOperations = m_VarOpsPlaceholder.find(name);
@@ -930,8 +1000,7 @@ VariableStruct *IO::InquireStructVariable(const std::string &name) noexcept
         return nullptr;
     }
 
-    VariableStruct *variable =
-        static_cast<VariableStruct *>(itVariable->second.get());
+    VariableStruct *variable = static_cast<VariableStruct *>(itVariable->second.get());
     if (m_ReadStreaming)
     {
         if (!variable->IsValidStep(m_EngineStep + 1))
@@ -942,8 +1011,7 @@ VariableStruct *IO::InquireStructVariable(const std::string &name) noexcept
     return variable;
 }
 
-VariableStruct *IO::InquireStructVariable(const std::string &name,
-                                          const StructDefinition &def,
+VariableStruct *IO::InquireStructVariable(const std::string &name, const StructDefinition &def,
                                           const bool allowReorganize) noexcept
 {
     auto ret = InquireStructVariable(name);
@@ -963,8 +1031,7 @@ VariableStruct *IO::InquireStructVariable(const std::string &name,
         {
             return nullptr;
         }
-        if (ret->m_WriteStructDefinition->Offset(i) != def.Offset(i) &&
-            !allowReorganize)
+        if (ret->m_WriteStructDefinition->Offset(i) != def.Offset(i) && !allowReorganize)
         {
             return nullptr;
         }
@@ -972,8 +1039,7 @@ VariableStruct *IO::InquireStructVariable(const std::string &name,
         {
             return nullptr;
         }
-        if (ret->m_WriteStructDefinition->ElementCount(i) !=
-            def.ElementCount(i))
+        if (ret->m_WriteStructDefinition->ElementCount(i) != def.ElementCount(i))
         {
             return nullptr;
         }
@@ -983,24 +1049,22 @@ VariableStruct *IO::InquireStructVariable(const std::string &name,
 }
 
 // Explicitly instantiate the necessary public template implementations
-#define define_template_instantiation(T)                                       \
-    template Variable<T> &IO::DefineVariable<T>(const std::string &,           \
-                                                const Dims &, const Dims &,    \
-                                                const Dims &, const bool);     \
+#define define_template_instantiation(T)                                                           \
+    template Variable<T> &IO::DefineVariable<T>(const std::string &, const Dims &, const Dims &,   \
+                                                const Dims &, const bool);                         \
     template Variable<T> *IO::InquireVariable<T>(const std::string &) noexcept;
 
 ADIOS2_FOREACH_STDTYPE_1ARG(define_template_instantiation)
 #undef define_template_instatiation
 
-#define declare_template_instantiation(T)                                      \
-    template Attribute<T> &IO::DefineAttribute<T>(                             \
-        const std::string &, const T *, const size_t, const std::string &,     \
-        const std::string, const bool);                                        \
-    template Attribute<T> &IO::DefineAttribute<T>(                             \
-        const std::string &, const T &, const std::string &,                   \
-        const std::string, const bool);                                        \
-    template Attribute<T> *IO::InquireAttribute<T>(                            \
-        const std::string &, const std::string &, const std::string) noexcept;
+#define declare_template_instantiation(T)                                                          \
+    template Attribute<T> &IO::DefineAttribute<T>(const std::string &, const T *, const size_t,    \
+                                                  const std::string &, const std::string,          \
+                                                  const bool);                                     \
+    template Attribute<T> &IO::DefineAttribute<T>(                                                 \
+        const std::string &, const T &, const std::string &, const std::string, const bool);       \
+    template Attribute<T> *IO::InquireAttribute<T>(const std::string &, const std::string &,       \
+                                                   const std::string) noexcept;
 
 ADIOS2_FOREACH_ATTRIBUTE_STDTYPE_1ARG(declare_template_instantiation)
 #undef declare_template_instantiation
