@@ -95,9 +95,8 @@ struct fabric_state
  *   plane would replace one or both of these with RDMA functionality.
  */
 
-static ucs_status_t init_fabric(struct fabric_state *fabric,
-                                struct _SstParams *Params, CP_Services Svcs,
-                                void *CP_Stream)
+static ucs_status_t init_fabric(struct fabric_state *fabric, struct _SstParams *Params,
+                                CP_Services Svcs, void *CP_Stream)
 {
     ucp_params_t ucp_params;
     ucp_worker_params_t worker_params;
@@ -112,8 +111,7 @@ static ucs_status_t init_fabric(struct fabric_state *fabric,
     if (status != UCS_OK)
     {
         Svcs->verbose(CP_Stream, DPCriticalVerbose,
-                      "UCX Error during ucp_config_read() with: %s.\n",
-                      ucs_status_string(status));
+                      "UCX Error during ucp_config_read() with: %s.\n", ucs_status_string(status));
         return status;
     }
     ucp_params.field_mask = UCP_PARAM_FIELD_FEATURES;
@@ -122,8 +120,7 @@ static ucs_status_t init_fabric(struct fabric_state *fabric,
     status = ucp_init(&ucp_params, config, &fabric->ucp_context);
     if (status != UCS_OK)
     {
-        Svcs->verbose(CP_Stream, DPCriticalVerbose,
-                      "UCX Error during ucp_init() with: %s.\n",
+        Svcs->verbose(CP_Stream, DPCriticalVerbose, "UCX Error during ucp_init() with: %s.\n",
                       ucs_status_string(status));
         return status;
     }
@@ -131,8 +128,7 @@ static ucs_status_t init_fabric(struct fabric_state *fabric,
 
     worker_params.field_mask = UCP_WORKER_PARAM_FIELD_THREAD_MODE;
     worker_params.thread_mode = UCS_THREAD_MODE_MULTI;
-    status = ucp_worker_create(fabric->ucp_context, &worker_params,
-                               &fabric->ucp_worker);
+    status = ucp_worker_create(fabric->ucp_context, &worker_params, &fabric->ucp_worker);
     if (status != UCS_OK)
     {
         Svcs->verbose(CP_Stream, DPCriticalVerbose,
@@ -140,8 +136,8 @@ static ucs_status_t init_fabric(struct fabric_state *fabric,
                       ucs_status_string(status));
         return status;
     }
-    status = ucp_worker_get_address(fabric->ucp_worker, &fabric->local_addr,
-                                    &fabric->local_addr_len);
+    status =
+        ucp_worker_get_address(fabric->ucp_worker, &fabric->local_addr, &fabric->local_addr_len);
     if (status != UCS_OK)
     {
         Svcs->verbose(CP_Stream, DPCriticalVerbose,
@@ -171,21 +167,21 @@ typedef struct _UcxCompletionHandle
     size_t Length;
     int Rank;
     int Pending;
-} * UcxCompletionHandle;
+} *UcxCompletionHandle;
 
 typedef struct _UcxBufferHandle
 {
     void *Block;
     size_t rkey_size;
     char *rkey;
-} * UcxBufferHandle;
+} *UcxBufferHandle;
 
 typedef struct _UcxBuffer
 {
     struct _UcxBufferHandle Handle;
     uint64_t BufferLen;
     uint64_t Offset;
-} * UcxBuffer;
+} *UcxBuffer;
 
 typedef struct _Ucx_RS_Stream
 {
@@ -200,7 +196,7 @@ typedef struct _Ucx_RS_Stream
     CP_PeerCohort PeerCohort;
     struct _UcxWriterContactInfo *WriterContactInfo;
     ucp_ep_h *WriterEP;
-} * Ucx_RS_Stream;
+} *Ucx_RS_Stream;
 
 typedef struct _TimestepEntry
 {
@@ -211,7 +207,7 @@ typedef struct _TimestepEntry
     ucp_mem_h memh;
     void *rkey;
     size_t rkey_size;
-} * TimestepList;
+} *TimestepList;
 
 typedef struct _Ucx_WSR_Stream
 {
@@ -219,7 +215,7 @@ typedef struct _Ucx_WSR_Stream
     CP_PeerCohort PeerCohort;
     int ReaderCohortSize;
     struct _UcxWriterContactInfo *WriterContactInfo;
-} * Ucx_WSR_Stream;
+} *Ucx_WSR_Stream;
 
 typedef struct _Ucx_WS_Stream
 {
@@ -232,24 +228,23 @@ typedef struct _Ucx_WS_Stream
 
     int ReaderCount;
     Ucx_WSR_Stream *Readers;
-} * Ucx_WS_Stream;
+} *Ucx_WS_Stream;
 
 typedef struct _UcxReaderContactInfo
 {
     void *RS_Stream;
-} * UcxReaderContactInfo;
+} *UcxReaderContactInfo;
 
 typedef struct _UcxWriterContactInfo
 {
     void *WS_Stream;
     size_t Length;
     void *Address;
-} * UcxWriterContactInfo;
+} *UcxWriterContactInfo;
 
-static DP_RS_Stream UcxInitReader(CP_Services Svcs, void *CP_Stream,
-                                  void **ReaderContactInfoPtr,
-                                  struct _SstParams *Params,
-                                  attr_list WriterContact, SstStats Stats)
+static DP_RS_Stream UcxInitReader(CP_Services Svcs, void *CP_Stream, void **ReaderContactInfoPtr,
+                                  struct _SstParams *Params, attr_list WriterContact,
+                                  SstStats Stats)
 {
     Ucx_RS_Stream Stream = malloc(sizeof(struct _Ucx_RS_Stream));
     SMPI_Comm comm = Svcs->getMPIComm(CP_Stream);
@@ -276,8 +271,7 @@ static DP_RS_Stream UcxInitReader(CP_Services Svcs, void *CP_Stream,
     status = init_fabric(Stream->Fabric, Stream->Params, Svcs, CP_Stream);
     if (status != UCS_OK)
     {
-        Svcs->verbose(CP_Stream, DPCriticalVerbose,
-                      "Could not find a valid transport fabric.\n");
+        Svcs->verbose(CP_Stream, DPCriticalVerbose, "Could not find a valid transport fabric.\n");
         if (Stream->Params)
         {
             free(Stream->Params);
@@ -288,9 +282,8 @@ static DP_RS_Stream UcxInitReader(CP_Services Svcs, void *CP_Stream,
     return Stream;
 }
 
-static DP_WS_Stream UcxInitWriter(CP_Services Svcs, void *CP_Stream,
-                                  struct _SstParams *Params, attr_list DPAttrs,
-                                  SstStats Stats)
+static DP_WS_Stream UcxInitWriter(CP_Services Svcs, void *CP_Stream, struct _SstParams *Params,
+                                  attr_list DPAttrs, SstStats Stats)
 {
     Ucx_WS_Stream Stream = malloc(sizeof(struct _Ucx_WS_Stream));
     SMPI_Comm comm = Svcs->getMPIComm(CP_Stream);
@@ -304,8 +297,7 @@ static DP_WS_Stream UcxInitWriter(CP_Services Svcs, void *CP_Stream,
     status = init_fabric(Stream->Fabric, Params, Svcs, CP_Stream);
     if (status != UCS_OK)
     {
-        Svcs->verbose(CP_Stream, DPCriticalVerbose,
-                      "Could not find a valid transport fabric.\n");
+        Svcs->verbose(CP_Stream, DPCriticalVerbose, "Could not find a valid transport fabric.\n");
         return NULL;
     }
 
@@ -314,10 +306,10 @@ static DP_WS_Stream UcxInitWriter(CP_Services Svcs, void *CP_Stream,
     return (void *)Stream;
 }
 
-static DP_WSR_Stream
-UcxInitWriterPerReader(CP_Services Svcs, DP_WS_Stream WS_Stream_v,
-                       int readerCohortSize, CP_PeerCohort PeerCohort,
-                       void **providedReaderInfo_v, void **WriterContactInfoPtr)
+static DP_WSR_Stream UcxInitWriterPerReader(CP_Services Svcs, DP_WS_Stream WS_Stream_v,
+                                            int readerCohortSize, CP_PeerCohort PeerCohort,
+                                            void **providedReaderInfo_v,
+                                            void **WriterContactInfoPtr)
 {
     Ucx_WS_Stream WS_Stream = (Ucx_WS_Stream)WS_Stream_v;
     Ucx_WSR_Stream WSR_Stream = malloc(sizeof(*WSR_Stream));
@@ -334,8 +326,8 @@ UcxInitWriterPerReader(CP_Services Svcs, DP_WS_Stream WS_Stream_v,
      * structure
      */
     pthread_mutex_lock(&ucx_wsr_mutex);
-    WS_Stream->Readers = realloc(
-        WS_Stream->Readers, sizeof(*WSR_Stream) * (WS_Stream->ReaderCount + 1));
+    WS_Stream->Readers =
+        realloc(WS_Stream->Readers, sizeof(*WSR_Stream) * (WS_Stream->ReaderCount + 1));
     WS_Stream->Readers[WS_Stream->ReaderCount] = WSR_Stream;
     WS_Stream->ReaderCount++;
     pthread_mutex_unlock(&ucx_wsr_mutex);
@@ -352,37 +344,31 @@ UcxInitWriterPerReader(CP_Services Svcs, DP_WS_Stream WS_Stream_v,
     return WSR_Stream;
 }
 
-static void UcxProvideWriterDataToReader(CP_Services Svcs,
-                                         DP_RS_Stream RS_Stream_v,
-                                         int writerCohortSize,
-                                         CP_PeerCohort PeerCohort,
+static void UcxProvideWriterDataToReader(CP_Services Svcs, DP_RS_Stream RS_Stream_v,
+                                         int writerCohortSize, CP_PeerCohort PeerCohort,
                                          void **providedWriterInfo_v)
 {
     Ucx_RS_Stream RS_Stream = (Ucx_RS_Stream)RS_Stream_v;
     FabricState Fabric = RS_Stream->Fabric;
-    UcxWriterContactInfo *providedWriterInfo =
-        (UcxWriterContactInfo *)providedWriterInfo_v;
+    UcxWriterContactInfo *providedWriterInfo = (UcxWriterContactInfo *)providedWriterInfo_v;
 
     RS_Stream->PeerCohort = PeerCohort;
     RS_Stream->WriterCohortSize = writerCohortSize;
-    RS_Stream->WriterEP =
-        calloc(writerCohortSize, sizeof(*RS_Stream->WriterEP));
+    RS_Stream->WriterEP = calloc(writerCohortSize, sizeof(*RS_Stream->WriterEP));
 
     /*
      * make a copy of writer contact information (original will not be
      * preserved)
      */
-    RS_Stream->WriterContactInfo =
-        malloc(sizeof(struct _UcxWriterContactInfo) * writerCohortSize);
+    RS_Stream->WriterContactInfo = malloc(sizeof(struct _UcxWriterContactInfo) * writerCohortSize);
     for (int i = 0; i < writerCohortSize; i++)
     {
-        RS_Stream->WriterContactInfo[i].WS_Stream =
-            providedWriterInfo[i]->WS_Stream;
+        RS_Stream->WriterContactInfo[i].WS_Stream = providedWriterInfo[i]->WS_Stream;
         ucp_ep_params_t ep_params;
         ep_params.field_mask = UCP_EP_PARAM_FIELD_REMOTE_ADDRESS;
         ep_params.address = providedWriterInfo[i]->Address;
-        ucs_status_t status = ucp_ep_create(Fabric->ucp_worker, &ep_params,
-                                            &RS_Stream->WriterEP[i]);
+        ucs_status_t status =
+            ucp_ep_create(Fabric->ucp_worker, &ep_params, &RS_Stream->WriterEP[i]);
         if (status != UCS_OK)
         {
             Svcs->verbose(RS_Stream->CP_Stream, DPCriticalVerbose,
@@ -396,10 +382,8 @@ static void UcxProvideWriterDataToReader(CP_Services Svcs,
     }
 }
 
-static void *UcxReadRemoteMemory(CP_Services Svcs, DP_RS_Stream Stream_v,
-                                 int Rank, long Timestep, size_t Offset,
-                                 size_t Length, void *Buffer,
-                                 void *DP_TimestepInfo)
+static void *UcxReadRemoteMemory(CP_Services Svcs, DP_RS_Stream Stream_v, int Rank, long Timestep,
+                                 size_t Offset, size_t Length, void *Buffer, void *DP_TimestepInfo)
 {
     Ucx_RS_Stream RS_Stream = (Ucx_RS_Stream)Stream_v;
     UcxBufferHandle Info = (UcxBufferHandle)DP_TimestepInfo;
@@ -407,8 +391,7 @@ static void *UcxReadRemoteMemory(CP_Services Svcs, DP_RS_Stream Stream_v,
     UcxCompletionHandle ret = malloc(sizeof(struct _UcxCompletionHandle));
 
     Svcs->verbose(RS_Stream->CP_Stream, DPTraceVerbose,
-                  "Performing remote read of Writer Rank %d at step %d\n", Rank,
-                  Timestep);
+                  "Performing remote read of Writer Rank %d at step %d\n", Rank, Timestep);
 
     if (!ret)
     {
@@ -426,8 +409,7 @@ static void *UcxReadRemoteMemory(CP_Services Svcs, DP_RS_Stream Stream_v,
     }
     else
     {
-        Svcs->verbose(RS_Stream->CP_Stream, DPCriticalVerbose,
-                      "Timestep info is null\n");
+        Svcs->verbose(RS_Stream->CP_Stream, DPCriticalVerbose, "Timestep info is null\n");
         free(ret);
         return NULL;
     }
@@ -438,14 +420,12 @@ static void *UcxReadRemoteMemory(CP_Services Svcs, DP_RS_Stream Stream_v,
     ret->Length = Length;
     ret->Pending = 1;
     Addr = (uint8_t *)Info->Block + Offset;
-    Svcs->verbose(
-        RS_Stream->CP_Stream, DPTraceVerbose,
-        "Remote read target is Rank %d, EP = %p (Offset = %zi, Length = %zi)\n",
-        Rank, RS_Stream->WriterEP[Rank], Offset, Length);
+    Svcs->verbose(RS_Stream->CP_Stream, DPTraceVerbose,
+                  "Remote read target is Rank %d, EP = %p (Offset = %zi, Length = %zi)\n", Rank,
+                  RS_Stream->WriterEP[Rank], Offset, Length);
 
     ucp_rkey_h rkey_p;
-    ucs_status_t status =
-        ucp_ep_rkey_unpack(RS_Stream->WriterEP[Rank], Info->rkey, &rkey_p);
+    ucs_status_t status = ucp_ep_rkey_unpack(RS_Stream->WriterEP[Rank], Info->rkey, &rkey_p);
     if (status != UCS_OK)
     {
         Svcs->verbose(RS_Stream->CP_Stream, DPCriticalVerbose,
@@ -456,26 +436,23 @@ static void *UcxReadRemoteMemory(CP_Services Svcs, DP_RS_Stream Stream_v,
     }
     ucp_request_param_t param;
     param.op_attr_mask = 0;
-    ret->req = ucp_get_nbx(RS_Stream->WriterEP[Rank], Buffer, Length,
-                           (uint64_t)Addr, rkey_p, &param);
+    ret->req =
+        ucp_get_nbx(RS_Stream->WriterEP[Rank], Buffer, Length, (uint64_t)Addr, rkey_p, &param);
     status = UCS_PTR_STATUS(ret->req);
     if (status != UCS_OK && status != UCS_INPROGRESS)
     {
         Svcs->verbose(RS_Stream->CP_Stream, DPCriticalVerbose,
-                      "UCX Error during ucp_get_nbx() with: %s.\n",
-                      ucs_status_string(status));
+                      "UCX Error during ucp_get_nbx() with: %s.\n", ucs_status_string(status));
         free(ret);
         return NULL;
     }
 
     Svcs->verbose(RS_Stream->CP_Stream, DPTraceVerbose,
-                  "Posted RDMA get for Writer Rank %d for handle %p\n", Rank,
-                  (void *)ret);
+                  "Posted RDMA get for Writer Rank %d for handle %p\n", Rank, (void *)ret);
     return (ret);
 }
 
-static void UcxNotifyConnFailure(CP_Services Svcs, DP_RS_Stream Stream_v,
-                                 int FailedPeerRank)
+static void UcxNotifyConnFailure(CP_Services Svcs, DP_RS_Stream Stream_v, int FailedPeerRank)
 {
     /* DP_RS_Stream is the return from InitReader */
     Ucx_RS_Stream Stream = (Ucx_RS_Stream)Stream_v;
@@ -509,8 +486,7 @@ static int UcxWaitForCompletion(CP_Services Svcs, void *Handle_v)
     }
     else if (UCS_PTR_STATUS(Handle->req) != UCS_OK)
     {
-        Svcs->verbose(Stream->CP_Stream, DPTraceVerbose,
-                      "RPC failed, not a pointer");
+        Svcs->verbose(Stream->CP_Stream, DPTraceVerbose, "RPC failed, not a pointer");
     }
     else
     { // UCS_OK request completed immediately. Call ucx callback.
@@ -525,8 +501,7 @@ static int UcxWaitForCompletion(CP_Services Svcs, void *Handle_v)
     return 0;
 }
 
-static void UcxProvideTimestep(CP_Services Svcs, DP_WS_Stream Stream_v,
-                               struct _SstData *Data,
+static void UcxProvideTimestep(CP_Services Svcs, DP_WS_Stream Stream_v, struct _SstData *Data,
                                struct _SstData *LocalMetadata, long Timestep,
                                void **TimestepInfoPtr)
 {
@@ -542,8 +517,7 @@ static void UcxProvideTimestep(CP_Services Svcs, DP_WS_Stream Stream_v,
     Entry->DP_TimestepInfo = Info;
 
     ucp_mem_map_params_t mem_map_params;
-    mem_map_params.field_mask = UCP_MEM_MAP_PARAM_FIELD_ADDRESS |
-                                UCP_MEM_MAP_PARAM_FIELD_LENGTH |
+    mem_map_params.field_mask = UCP_MEM_MAP_PARAM_FIELD_ADDRESS | UCP_MEM_MAP_PARAM_FIELD_LENGTH |
                                 UCP_MEM_MAP_PARAM_FIELD_FLAGS;
     mem_map_params.address = Data->block;
     mem_map_params.length = Data->DataSize;
@@ -551,11 +525,10 @@ static void UcxProvideTimestep(CP_Services Svcs, DP_WS_Stream Stream_v,
     status = ucp_mem_map(Fabric->ucp_context, &mem_map_params, &Entry->memh);
     if (status != UCS_OK)
     {
-        Svcs->verbose(
-            Stream->CP_Stream, DPCriticalVerbose,
-            "UCX Error during ucp_mem_map() with: %s. while providing timestep "
-            "data with block %p and access key %d.\n",
-            ucs_status_string(status), Info->Block, Info->rkey);
+        Svcs->verbose(Stream->CP_Stream, DPCriticalVerbose,
+                      "UCX Error during ucp_mem_map() with: %s. while providing timestep "
+                      "data with block %p and access key %d.\n",
+                      ucs_status_string(status), Info->Block, Info->rkey);
         return;
     }
 
@@ -564,24 +537,21 @@ static void UcxProvideTimestep(CP_Services Svcs, DP_WS_Stream Stream_v,
     status = ucp_mem_query(Entry->memh, &mem_attr);
     if (status != UCS_OK)
     {
-        Svcs->verbose(
-            Stream->CP_Stream, DPCriticalVerbose,
-            "UCX Error during ucp_mem_query() with: %s. while providing "
-            "timestep data with block %p and access key %d.\n",
-            ucs_status_string(status), Info->Block, Info->rkey);
+        Svcs->verbose(Stream->CP_Stream, DPCriticalVerbose,
+                      "UCX Error during ucp_mem_query() with: %s. while providing "
+                      "timestep data with block %p and access key %d.\n",
+                      ucs_status_string(status), Info->Block, Info->rkey);
         return;
     }
     Data->block = mem_attr.address;
 
-    status = ucp_rkey_pack(Fabric->ucp_context, Entry->memh, &Entry->rkey,
-                           &Entry->rkey_size);
+    status = ucp_rkey_pack(Fabric->ucp_context, Entry->memh, &Entry->rkey, &Entry->rkey_size);
     if (status != UCS_OK)
     {
-        Svcs->verbose(
-            Stream->CP_Stream, DPCriticalVerbose,
-            "UCX Error during ucp_rkey_pack() with: %s. while providing "
-            "timestep data with block %p and access key %d.\n",
-            ucs_status_string(status), Info->Block, Info->rkey);
+        Svcs->verbose(Stream->CP_Stream, DPCriticalVerbose,
+                      "UCX Error during ucp_rkey_pack() with: %s. while providing "
+                      "timestep data with block %p and access key %d.\n",
+                      ucs_status_string(status), Info->Block, Info->rkey);
         return;
     }
     pthread_mutex_lock(&ucx_ts_mutex);
@@ -594,22 +564,20 @@ static void UcxProvideTimestep(CP_Services Svcs, DP_WS_Stream Stream_v,
     Info->Block = (uint8_t *)Data->block;
 
     Svcs->verbose(Stream->CP_Stream, DPTraceVerbose,
-                  "Providing timestep data with block %p and access key %d\n",
-                  Info->Block, Info->rkey);
+                  "Providing timestep data with block %p and access key %d\n", Info->Block,
+                  Info->rkey);
 
     *TimestepInfoPtr = Info;
 }
 
-static void UcxReleaseTimestep(CP_Services Svcs, DP_WS_Stream Stream_v,
-                               long Timestep)
+static void UcxReleaseTimestep(CP_Services Svcs, DP_WS_Stream Stream_v, long Timestep)
 {
     Ucx_WS_Stream Stream = (Ucx_WS_Stream)Stream_v;
     FabricState Fabric = Stream->Fabric;
     TimestepList *List = &Stream->Timesteps;
     TimestepList ReleaseTSL;
 
-    Svcs->verbose(Stream->CP_Stream, DPTraceVerbose, "Releasing timestep %ld\n",
-                  Timestep);
+    Svcs->verbose(Stream->CP_Stream, DPTraceVerbose, "Releasing timestep %ld\n", Timestep);
 
     pthread_mutex_lock(&ucx_ts_mutex);
     while ((*List) && (*List)->Timestep != Timestep)
@@ -635,8 +603,7 @@ static void UcxReleaseTimestep(CP_Services Svcs, DP_WS_Stream Stream_v,
     ucs_status_t status = ucp_mem_unmap(Fabric->ucp_context, ReleaseTSL->memh);
     if (status != UCS_OK)
     {
-        Svcs->verbose(Stream->CP_Stream, DPCriticalVerbose,
-                      "UCX Error during ucp_mem_unmap: %s.\n",
+        Svcs->verbose(Stream->CP_Stream, DPCriticalVerbose, "UCX Error during ucp_mem_unmap: %s.\n",
                       ucs_status_string(status));
         return;
     }
@@ -651,8 +618,7 @@ static void UcxDestroyReader(CP_Services Svcs, DP_RS_Stream RS_Stream_v)
 {
     Ucx_RS_Stream RS_Stream = (Ucx_RS_Stream)RS_Stream_v;
 
-    Svcs->verbose(RS_Stream->CP_Stream, DPTraceVerbose,
-                  "Tearing down RDMA state on reader.\n");
+    Svcs->verbose(RS_Stream->CP_Stream, DPTraceVerbose, "Tearing down RDMA state on reader.\n");
     if (RS_Stream->Fabric)
     {
         fini_fabric(RS_Stream->Fabric);
@@ -662,8 +628,7 @@ static void UcxDestroyReader(CP_Services Svcs, DP_RS_Stream RS_Stream_v)
     free(RS_Stream);
 }
 
-static void UcxDestroyWriterPerReader(CP_Services Svcs,
-                                      DP_WSR_Stream WSR_Stream_v)
+static void UcxDestroyWriterPerReader(CP_Services Svcs, DP_WSR_Stream WSR_Stream_v)
 {
     Ucx_WSR_Stream WSR_Stream = {0};
     memcpy(&WSR_Stream, &WSR_Stream_v, sizeof(Ucx_WSR_Stream));
@@ -674,14 +639,13 @@ static void UcxDestroyWriterPerReader(CP_Services Svcs,
     {
         if (WS_Stream->Readers[i] == WSR_Stream)
         {
-            WS_Stream->Readers[i] =
-                WS_Stream->Readers[WS_Stream->ReaderCount - 1];
+            WS_Stream->Readers[i] = WS_Stream->Readers[WS_Stream->ReaderCount - 1];
             break;
         }
     }
 
-    WS_Stream->Readers = realloc(
-        WS_Stream->Readers, sizeof(*WSR_Stream) * (WS_Stream->ReaderCount - 1));
+    WS_Stream->Readers =
+        realloc(WS_Stream->Readers, sizeof(*WSR_Stream) * (WS_Stream->ReaderCount - 1));
     WS_Stream->ReaderCount--;
     pthread_mutex_unlock(&ucx_wsr_mutex);
 
@@ -694,25 +658,21 @@ static void UcxDestroyWriterPerReader(CP_Services Svcs,
 }
 
 static FMField UcxReaderContactList[] = {
-    {"reader_ID", "integer", sizeof(void *),
-     FMOffset(UcxReaderContactInfo, RS_Stream)},
+    {"reader_ID", "integer", sizeof(void *), FMOffset(UcxReaderContactInfo, RS_Stream)},
     {NULL, NULL, 0, 0}};
 
 static FMStructDescRec UcxReaderContactStructs[] = {
-    {"UcxReaderContactInfo", UcxReaderContactList,
-     sizeof(struct _UcxReaderContactInfo), NULL},
+    {"UcxReaderContactInfo", UcxReaderContactList, sizeof(struct _UcxReaderContactInfo), NULL},
     {NULL, NULL, 0, NULL}};
 
 static FMField UcxBufferHandleList[] = {
     {"Block", "integer", sizeof(void *), FMOffset(UcxBufferHandle, Block)},
-    {"rkey_size", "integer", sizeof(size_t),
-     FMOffset(UcxBufferHandle, rkey_size)},
+    {"rkey_size", "integer", sizeof(size_t), FMOffset(UcxBufferHandle, rkey_size)},
     {"rkey", "char[rkey_size]", sizeof(char), FMOffset(UcxBufferHandle, rkey)},
     {NULL, NULL, 0, 0}};
 
 static FMStructDescRec UcxBufferHandleStructs[] = {
-    {"UcxBufferHandle", UcxBufferHandleList, sizeof(struct _UcxBufferHandle),
-     NULL},
+    {"UcxBufferHandle", UcxBufferHandleList, sizeof(struct _UcxBufferHandle), NULL},
     {NULL, NULL, 0, NULL}};
 
 static void UcxDestroyWriter(CP_Services Svcs, DP_WS_Stream WS_Stream_v)
@@ -727,8 +687,7 @@ static void UcxDestroyWriter(CP_Services Svcs, DP_WS_Stream WS_Stream_v)
         UcxDestroyWriterPerReader(Svcs, WS_Stream->Readers[0]);
     }
 
-    Svcs->verbose(WS_Stream->CP_Stream, DPTraceVerbose,
-                  "Releasing remaining timesteps.\n");
+    Svcs->verbose(WS_Stream->CP_Stream, DPTraceVerbose, "Releasing remaining timesteps.\n");
 
     pthread_mutex_lock(&ucx_ts_mutex);
     while (WS_Stream->Timesteps)
@@ -740,8 +699,7 @@ static void UcxDestroyWriter(CP_Services Svcs, DP_WS_Stream WS_Stream_v)
     }
     pthread_mutex_unlock(&ucx_ts_mutex);
 
-    Svcs->verbose(WS_Stream->CP_Stream, DPTraceVerbose,
-                  "Tearing down RDMA state on writer.\n");
+    Svcs->verbose(WS_Stream->CP_Stream, DPTraceVerbose, "Tearing down RDMA state on writer.\n");
 
     if (WS_Stream->Fabric)
     {
@@ -753,22 +711,18 @@ static void UcxDestroyWriter(CP_Services Svcs, DP_WS_Stream WS_Stream_v)
 }
 
 static FMField UcxWriterContactList[] = {
-    {"writer_ID", "integer", sizeof(void *),
-     FMOffset(UcxWriterContactInfo, WS_Stream)},
+    {"writer_ID", "integer", sizeof(void *), FMOffset(UcxWriterContactInfo, WS_Stream)},
     {"Length", "integer", sizeof(int), FMOffset(UcxWriterContactInfo, Length)},
-    {"Address", "integer[Length]", sizeof(char),
-     FMOffset(UcxWriterContactInfo, Address)},
+    {"Address", "integer[Length]", sizeof(char), FMOffset(UcxWriterContactInfo, Address)},
     {NULL, NULL, 0, 0}};
 
 static FMStructDescRec UcxWriterContactStructs[] = {
-    {"UcxWriterContactInfo", UcxWriterContactList,
-     sizeof(struct _UcxWriterContactInfo), NULL},
+    {"UcxWriterContactInfo", UcxWriterContactList, sizeof(struct _UcxWriterContactInfo), NULL},
     {NULL, NULL, 0, NULL}};
 
 static struct _CP_DP_Interface UcxDPInterface = {0};
 
-static int UcxGetPriority(CP_Services Svcs, void *CP_Stream,
-                          struct _SstParams *Params)
+static int UcxGetPriority(CP_Services Svcs, void *CP_Stream, struct _SstParams *Params)
 {
     /* TODO: Improve priority algorithm */
     int ux_dp_priority = 10;
@@ -785,14 +739,13 @@ static void UcxUnGetPriority(CP_Services Svcs, void *CP_Stream)
     Svcs->verbose(CP_Stream, DPPerStepVerbose, "UCX Dataplane unloading\n");
 }
 
-static void UcxTimestepArrived(CP_Services Svcs, DP_RS_Stream Stream_v,
-                               long Timestep, SstPreloadModeType PreloadMode)
+static void UcxTimestepArrived(CP_Services Svcs, DP_RS_Stream Stream_v, long Timestep,
+                               SstPreloadModeType PreloadMode)
 {
     Ucx_RS_Stream Stream = (Ucx_RS_Stream)Stream_v;
 
-    Svcs->verbose(Stream->CP_Stream, DPTraceVerbose,
-                  "%s with Timestep = %li, PreloadMode = %d\n", __func__,
-                  Timestep, PreloadMode);
+    Svcs->verbose(Stream->CP_Stream, DPTraceVerbose, "%s with Timestep = %li, PreloadMode = %d\n",
+                  __func__, Timestep, PreloadMode);
 }
 
 extern NO_SANITIZE_THREAD CP_DP_Interface LoadUcxDP()
