@@ -7,8 +7,7 @@
 
 #include "decomp.h"
 
-void decompColumnMajor(const size_t ndim, const size_t rank,
-                       const size_t *decomp, size_t *pos)
+void decompColumnMajor(const size_t ndim, const size_t rank, const size_t *decomp, size_t *pos)
 {
     // pos[k] = rank / prod(decomp[i], i=0..k-1) % decomp[k]
 
@@ -20,8 +19,7 @@ void decompColumnMajor(const size_t ndim, const size_t rank,
     }
 }
 
-void decompRowMajor(const size_t ndim, const size_t rank, const size_t *decomp,
-                    size_t *pos)
+void decompRowMajor(const size_t ndim, const size_t rank, const size_t *decomp, size_t *pos)
 {
     // pos[k] = rank / prod(decomp[i], i=k+1..n-1) % decomp[k]
 
