@@ -47,8 +47,7 @@ namespace adios2
 namespace utils
 {
 
-Reorganize::Reorganize(int argc, char *argv[])
-: Utils("adios_reorganize", argc, argv)
+Reorganize::Reorganize(int argc, char *argv[]) : Utils("adios_reorganize", argc, argv)
 {
 #if ADIOS2_USE_MPI
     {
@@ -64,9 +63,8 @@ Reorganize::Reorganize(int argc, char *argv[])
     if (argc < 7)
     {
         PrintUsage();
-        helper::Throw<std::invalid_argument>(
-            "Utils", "AdiosReorganize", "Reorganize",
-            "Not enough arguments. At least 6 are required");
+        helper::Throw<std::invalid_argument>("Utils", "AdiosReorganize", "Reorganize",
+                                             "Not enough arguments. At least 6 are required");
     }
     infilename = std::string(argv[1]);
     outfilename = std::string(argv[2]);
@@ -84,12 +82,10 @@ Reorganize::Reorganize(int argc, char *argv[])
         decomp_values[nd] = std::strtol(argv[j], &end, 10);
         if (errno || (end != 0 && *end != '\0'))
         {
-            std::string errmsg(
-                "ERROR: Invalid decomposition number in argument " +
-                std::to_string(j) + ": '" + std::string(argv[j]) + "'\n");
+            std::string errmsg("ERROR: Invalid decomposition number in argument " +
+                               std::to_string(j) + ": '" + std::string(argv[j]) + "'\n");
             PrintUsage();
-            helper::Throw<std::invalid_argument>("Utils", "AdiosReorganize",
-                                                 "Reorganize", errmsg);
+            helper::Throw<std::invalid_argument>("Utils", "AdiosReorganize", "Reorganize", errmsg);
         }
         nd++;
         j++;
@@ -97,9 +93,8 @@ Reorganize::Reorganize(int argc, char *argv[])
 
     if (argc > j)
     {
-        helper::Throw<std::invalid_argument>(
-            "Utils", "AdiosReorganize", "Reorganize",
-            "Up to 6 decomposition arguments are supported");
+        helper::Throw<std::invalid_argument>("Utils", "AdiosReorganize", "Reorganize",
+                                             "Up to 6 decomposition arguments are supported");
     }
 
     int prod = 1;
@@ -113,12 +108,10 @@ Reorganize::Reorganize(int argc, char *argv[])
         print0("ERROR: Product of decomposition numbers %d > number of "
                "processes %d\n",
                prod, m_Size);
-        std::string errmsg("ERROR: The product of decomposition numbers " +
-                           std::to_string(prod) + " > number of processes " +
-                           std::to_string(m_Size) + "\n");
+        std::string errmsg("ERROR: The product of decomposition numbers " + std::to_string(prod) +
+                           " > number of processes " + std::to_string(m_Size) + "\n");
         PrintUsage();
-        helper::Throw<std::invalid_argument>("Utils", "AdiosReorganize",
-                                             "Reorganize", errmsg);
+        helper::Throw<std::invalid_argument>("Utils", "AdiosReorganize", "Reorganize", errmsg);
     }
 }
 
@@ -154,16 +147,14 @@ void Reorganize::Run()
     int curr_step = -1;
     while (true)
     {
-        adios2::StepStatus status =
-            rStream.BeginStep(adios2::StepMode::Read, 10.0);
+        adios2::StepStatus status = rStream.BeginStep(adios2::StepMode::Read, 10.0);
         if (status == adios2::StepStatus::NotReady)
         {
             if (handleAsStream)
             {
                 if (!m_Rank)
                 {
-                    std::cout << " No new steps arrived in a while "
-                              << std::endl;
+                    std::cout << " No new steps arrived in a while " << std::endl;
                 }
                 continue;
             }
@@ -171,13 +162,12 @@ void Reorganize::Run()
             {
                 if (!m_Rank)
                 {
-                    std::cout
-                        << " Timeout waiting for next step. If this is "
-                           "a live stream through file, use a different "
-                           "reading engine, like FileStream or BP4. "
-                           "If it is an unclosed BP file, you may manually "
-                           "close it with using adios_deactive_bp.sh."
-                        << std::endl;
+                    std::cout << " Timeout waiting for next step. If this is "
+                                 "a live stream through file, use a different "
+                                 "reading engine, like FileStream or BP4. "
+                                 "If it is an unclosed BP file, you may manually "
+                                 "close it with using adios_deactive_bp.sh."
+                              << std::endl;
                 }
                 break;
             }
@@ -192,9 +182,8 @@ void Reorganize::Run()
         if (rStream.CurrentStep() != static_cast<size_t>(curr_step + 1))
         {
             // we missed some steps
-            std::cout << "rank " << m_Rank << " WARNING: steps " << curr_step
-                      << ".." << rStream.CurrentStep() - 1
-                      << "were missed when advancing." << std::endl;
+            std::cout << "rank " << m_Rank << " WARNING: steps " << curr_step << ".."
+                      << rStream.CurrentStep() - 1 << "were missed when advancing." << std::endl;
         }
 
         curr_step = static_cast<int>(rStream.CurrentStep());
@@ -224,7 +213,7 @@ void Reorganize::Run()
 
 // PRIVATE
 template <typename Arg, typename... Args>
-void Reorganize::osprint0(std::ostream &out, Arg &&arg, Args &&... args)
+void Reorganize::osprint0(std::ostream &out, Arg &&arg, Args &&...args)
 {
     if (!m_Rank)
     {
@@ -236,7 +225,7 @@ void Reorganize::osprint0(std::ostream &out, Arg &&arg, Args &&... args)
 }
 
 template <typename Arg, typename... Args>
-void Reorganize::print0(Arg &&arg, Args &&... args)
+void Reorganize::print0(Arg &&arg, Args &&...args)
 {
     if (!m_Rank)
     {
@@ -288,32 +277,31 @@ void Reorganize::ProcessParameters()
 
 void Reorganize::PrintUsage() const noexcept
 {
-    std::cout
-        << "Usage: adios_reorganize input output rmethod \"params\" wmethod "
-           "\"params\" "
-           "<decomposition>\n"
-           "    input   Input stream path\n"
-           "    output  Output file path\n"
-           "    rmethod ADIOS method to read with\n"
-           "            Supported read methods: BPFile, HDF5, SST, SSC, "
-           "DataMan\n"
-           "    params  Read method parameters (in quotes; comma-separated "
-           "list)\n"
-           "    wmethod ADIOS method to write with\n"
-           "    params  Write method parameters (in quotes; comma-separated "
-           "list)\n"
-           "    <decomposition>    list of numbers e.g. 32 8 4\n"
-           "            Decomposition values in each dimension of an array\n"
-           "            The product of these number must be less then the "
-           "number\n"
-           "            of processes. Processes whose rank is higher than the\n"
-           "            product, will not write anything.\n"
-           "               Arrays with less dimensions than the number of "
-           "values,\n"
-           "            will be decomposed with using the appropriate number "
-           "of\n"
-           "            values."
-        << std::endl;
+    std::cout << "Usage: adios_reorganize input output rmethod \"params\" wmethod "
+                 "\"params\" "
+                 "<decomposition>\n"
+                 "    input   Input stream path\n"
+                 "    output  Output file path\n"
+                 "    rmethod ADIOS method to read with\n"
+                 "            Supported read methods: BPFile, HDF5, SST, SSC, "
+                 "DataMan\n"
+                 "    params  Read method parameters (in quotes; comma-separated "
+                 "list)\n"
+                 "    wmethod ADIOS method to write with\n"
+                 "    params  Write method parameters (in quotes; comma-separated "
+                 "list)\n"
+                 "    <decomposition>    list of numbers e.g. 32 8 4\n"
+                 "            Decomposition values in each dimension of an array\n"
+                 "            The product of these number must be less then the "
+                 "number\n"
+                 "            of processes. Processes whose rank is higher than the\n"
+                 "            product, will not write anything.\n"
+                 "               Arrays with less dimensions than the number of "
+                 "values,\n"
+                 "            will be decomposed with using the appropriate number "
+                 "of\n"
+                 "            values."
+              << std::endl;
 }
 
 void Reorganize::PrintExamples() const noexcept {}
@@ -357,9 +345,8 @@ std::string Reorganize::VectorToString(const T &v)
     return s;
 }
 
-size_t
-Reorganize::Decompose(int numproc, int rank, VarInfo &vi,
-                      const int *np // number of processes in each dimension
+size_t Reorganize::Decompose(int numproc, int rank, VarInfo &vi,
+                             const int *np // number of processes in each dimension
 )
 {
     size_t writesize = 0;
@@ -439,14 +426,13 @@ Reorganize::Decompose(int numproc, int rank, VarInfo &vi,
     std::string ints = VectorToString(pos);
     if (pos[ndim - 1] >= np[ndim - 1])
     {
-        std::cout << "rank " << rank << ": position in " << ndim
-                  << "-D decomposition = " << ints
+        std::cout << "rank " << rank << ": position in " << ndim << "-D decomposition = " << ints
                   << " ---> Out of bound process" << std::endl;
     }
     else
     {
-        std::cout << "rank " << rank << ": position in " << ndim
-                  << "-D decomposition = " << ints << std::endl;
+        std::cout << "rank " << rank << ": position in " << ndim << "-D decomposition = " << ints
+                  << std::endl;
     }
 
     /* Decompose each dimension according to the position */
@@ -475,16 +461,15 @@ Reorganize::Decompose(int numproc, int rank, VarInfo &vi,
         writesize *= count;
     }
     ints = VectorToString(vi.count);
-    std::cout << "rank " << rank << ": ldims in " << ndim << "-D space = {"
-              << ints << "}" << std::endl;
+    std::cout << "rank " << rank << ": ldims in " << ndim << "-D space = {" << ints << "}"
+              << std::endl;
     ints = VectorToString(vi.start);
-    std::cout << "rank " << rank << ": offsets in " << ndim << "-D space = {"
-              << ints << "}" << std::endl;
+    std::cout << "rank " << rank << ": offsets in " << ndim << "-D space = {" << ints << "}"
+              << std::endl;
     return writesize;
 }
 
-int Reorganize::ProcessMetadata(core::Engine &rStream, core::IO &io,
-                                const core::VarMap &variables,
+int Reorganize::ProcessMetadata(core::Engine &rStream, core::IO &io, const core::VarMap &variables,
                                 const core::AttrMap &attributes, int step)
 {
     int retval = 0;
@@ -507,17 +492,25 @@ int Reorganize::ProcessMetadata(core::Engine &rStream, core::IO &io,
         {
             // not supported
         }
-#define declare_template_instantiation(T)                                      \
-    else if (type == helper::GetDataType<T>())                                 \
-    {                                                                          \
-        core::Variable<T> *v = io.InquireVariable<T>(variablePair.first);      \
-        if (v->m_ShapeID == adios2::ShapeID::LocalArray)                       \
-        {                                                                      \
-                                                                               \
-            auto blocks = rStream.BlocksInfo(*v, rStream.CurrentStep());       \
-            nBlocks = blocks.size();                                           \
-        }                                                                      \
-        variable = v;                                                          \
+#define declare_template_instantiation(T)                                                          \
+    else if (type == helper::GetDataType<T>())                                                     \
+    {                                                                                              \
+        core::Variable<T> *v = io.InquireVariable<T>(variablePair.first);                          \
+        if (v->m_ShapeID == adios2::ShapeID::LocalArray)                                           \
+        {                                                                                          \
+                                                                                                   \
+            const auto minBlocks = rStream.MinBlocksInfo(*v, step);                                \
+            if (minBlocks)                                                                         \
+            {                                                                                      \
+                nBlocks = minBlocks->BlocksInfo.size();                                            \
+            }                                                                                      \
+            else                                                                                   \
+            {                                                                                      \
+                auto blocks = rStream.BlocksInfo(*v, rStream.CurrentStep());                       \
+                nBlocks = blocks.size();                                                           \
+            }                                                                                      \
+        }                                                                                          \
+        variable = v;                                                                              \
     }
         ADIOS2_FOREACH_STDTYPE_1ARG(declare_template_instantiation)
 #undef declare_template_instantiation
@@ -555,11 +548,10 @@ int Reorganize::ProcessMetadata(core::Engine &rStream, core::IO &io,
                 print0("\t local array ");
                 if (nBlocks > 1)
                 {
-                    print0(
-                        "ERROR: adios_reorganize does not support Local Arrays "
-                        "except when there is only 1 written block in each "
-                        "step. This one has ",
-                        nBlocks, " blocks in this step ");
+                    print0("ERROR: adios_reorganize does not support Local Arrays "
+                           "except when there is only 1 written block in each "
+                           "step. This one has ",
+                           nBlocks, " blocks in this step ");
                     return 1;
                 }
             }
@@ -570,8 +562,7 @@ int Reorganize::ProcessMetadata(core::Engine &rStream, core::IO &io,
             }
 
             // determine subset we will write
-            size_t sum_count =
-                Decompose(m_Size, m_Rank, varinfo[varidx], decomp_values);
+            size_t sum_count = Decompose(m_Size, m_Rank, varinfo[varidx], decomp_values);
             varinfo[varidx].writesize = sum_count * variable->m_ElementSize;
 
             if (varinfo[varidx].writesize != 0)
@@ -589,14 +580,12 @@ int Reorganize::ProcessMetadata(core::Engine &rStream, core::IO &io,
     }
 
     // determine output buffer size
-    size_t bufsize =
-        write_total + variables.size() * 200 + attributes.size() * 32 + 1024;
+    size_t bufsize = write_total + variables.size() * 200 + attributes.size() * 32 + 1024;
     if (bufsize > max_write_buffer_size)
     {
         helper::Log("Util", "Reorganize", "ProcessMetadata",
-                    "write buffer size needs to hold about " +
-                        std::to_string(bufsize) + " bytes but max is set to " +
-                        std::to_string(max_write_buffer_size),
+                    "write buffer size needs to hold about " + std::to_string(bufsize) +
+                        " bytes but max is set to " + std::to_string(max_write_buffer_size),
                     m_Rank, m_Rank, 0, 0, helper::FATALERROR);
         return 1;
     }
@@ -604,31 +593,27 @@ int Reorganize::ProcessMetadata(core::Engine &rStream, core::IO &io,
     if (largest_block > max_read_buffer_size)
     {
         helper::Log("Util", "Reorganize", "ProcessMetadata",
-                    "read buffer size needs to hold at least " +
-                        std::to_string(largest_block) +
-                        " bytes but max is set to " +
-                        std::to_string(max_read_buffer_size),
+                    "read buffer size needs to hold at least " + std::to_string(largest_block) +
+                        " bytes but max is set to " + std::to_string(max_read_buffer_size),
                     m_Rank, m_Rank, 0, 0, helper::FATALERROR);
         return 1;
     }
     return retval;
 }
 
-int Reorganize::ReadWrite(core::Engine &rStream, core::Engine &wStream,
-                          core::IO &io, const core::VarMap &variables, int step)
+int Reorganize::ReadWrite(core::Engine &rStream, core::Engine &wStream, core::IO &io,
+                          const core::VarMap &variables, int step)
 {
     int retval = 0;
 
     size_t nvars = variables.size();
     if (nvars != varinfo.size())
     {
-        helper::Log(
-            "Util", "Reorganize", "ReadWrite",
-            "Invalid program state, number of variables (" +
-                std::to_string(nvars) +
-                ") to read does not match the number of processed variables (" +
-                std::to_string(varinfo.size()) + ")",
-            m_Rank, m_Rank, 0, 0, helper::FATALERROR);
+        helper::Log("Util", "Reorganize", "ReadWrite",
+                    "Invalid program state, number of variables (" + std::to_string(nvars) +
+                        ") to read does not match the number of processed variables (" +
+                        std::to_string(varinfo.size()) + ")",
+                    m_Rank, m_Rank, 0, 0, helper::FATALERROR);
     }
 
     /*
@@ -643,30 +628,26 @@ int Reorganize::ReadWrite(core::Engine &rStream, core::Engine &wStream,
             if (varinfo[varidx].writesize != 0)
             {
                 // read variable subset
-                std::cout << "rank " << m_Rank << ": Read variable " << name
-                          << std::endl;
+                std::cout << "rank " << m_Rank << ": Read variable " << name << std::endl;
                 const DataType type = variables.at(name)->m_Type;
                 if (type == DataType::Struct)
                 {
                     // not supported
                 }
-#define declare_template_instantiation(T)                                      \
-    else if (type == helper::GetDataType<T>())                                 \
-    {                                                                          \
-        varinfo[varidx].readbuf = calloc(1, varinfo[varidx].writesize);        \
-        if (varinfo[varidx].count.size() == 0)                                 \
-        {                                                                      \
-            rStream.Get<T>(name,                                               \
-                           reinterpret_cast<T *>(varinfo[varidx].readbuf),     \
-                           adios2::Mode::Sync);                                \
-        }                                                                      \
-        else                                                                   \
-        {                                                                      \
-            varinfo[varidx].v->SetSelection(                                   \
-                {varinfo[varidx].start, varinfo[varidx].count});               \
-            rStream.Get<T>(name,                                               \
-                           reinterpret_cast<T *>(varinfo[varidx].readbuf));    \
-        }                                                                      \
+#define declare_template_instantiation(T)                                                          \
+    else if (type == helper::GetDataType<T>())                                                     \
+    {                                                                                              \
+        varinfo[varidx].readbuf = calloc(1, varinfo[varidx].writesize);                            \
+        if (varinfo[varidx].count.size() == 0)                                                     \
+        {                                                                                          \
+            rStream.Get<T>(name, reinterpret_cast<T *>(varinfo[varidx].readbuf),                   \
+                           adios2::Mode::Sync);                                                    \
+        }                                                                                          \
+        else                                                                                       \
+        {                                                                                          \
+            varinfo[varidx].v->SetSelection({varinfo[varidx].start, varinfo[varidx].count});       \
+            rStream.Get<T>(name, reinterpret_cast<T *>(varinfo[varidx].readbuf));                  \
+        }                                                                                          \
     }
                 ADIOS2_FOREACH_STDTYPE_1ARG(declare_template_instantiation)
 #undef declare_template_instantiation
@@ -687,35 +668,30 @@ int Reorganize::ReadWrite(core::Engine &rStream, core::Engine &wStream,
             if (varinfo[varidx].writesize != 0)
             {
                 // Write variable subset
-                std::cout << "rank " << m_Rank << ": Write variable " << name
-                          << std::endl;
+                std::cout << "rank " << m_Rank << ": Write variable " << name << std::endl;
                 const DataType type = variables.at(name)->m_Type;
                 if (type == DataType::Struct)
                 {
                     // not supported
                 }
-#define declare_template_instantiation(T)                                      \
-    else if (type == helper::GetDataType<T>())                                 \
-    {                                                                          \
-        if (varinfo[varidx].count.size() == 0)                                 \
-        {                                                                      \
-            wStream.Put<T>(name,                                               \
-                           reinterpret_cast<T *>(varinfo[varidx].readbuf),     \
-                           adios2::Mode::Sync);                                \
-        }                                                                      \
-        else if (varinfo[varidx].v->m_ShapeID == adios2::ShapeID::LocalArray)  \
-        {                                                                      \
-            wStream.Put<T>(name,                                               \
-                           reinterpret_cast<T *>(varinfo[varidx].readbuf),     \
-                           adios2::Mode::Sync);                                \
-        }                                                                      \
-        else                                                                   \
-        {                                                                      \
-            varinfo[varidx].v->SetSelection(                                   \
-                {varinfo[varidx].start, varinfo[varidx].count});               \
-            wStream.Put<T>(name,                                               \
-                           reinterpret_cast<T *>(varinfo[varidx].readbuf));    \
-        }                                                                      \
+#define declare_template_instantiation(T)                                                          \
+    else if (type == helper::GetDataType<T>())                                                     \
+    {                                                                                              \
+        if (varinfo[varidx].count.size() == 0)                                                     \
+        {                                                                                          \
+            wStream.Put<T>(name, reinterpret_cast<T *>(varinfo[varidx].readbuf),                   \
+                           adios2::Mode::Sync);                                                    \
+        }                                                                                          \
+        else if (varinfo[varidx].v->m_ShapeID == adios2::ShapeID::LocalArray)                      \
+        {                                                                                          \
+            wStream.Put<T>(name, reinterpret_cast<T *>(varinfo[varidx].readbuf),                   \
+                           adios2::Mode::Sync);                                                    \
+        }                                                                                          \
+        else                                                                                       \
+        {                                                                                          \
+            varinfo[varidx].v->SetSelection({varinfo[varidx].start, varinfo[varidx].count});       \
+            wStream.Put<T>(name, reinterpret_cast<T *>(varinfo[varidx].readbuf));                  \
+        }                                                                                          \
     }
                 ADIOS2_FOREACH_STDTYPE_1ARG(declare_template_instantiation)
 #undef declare_template_instantiation
