@@ -22,8 +22,7 @@ namespace
 {
 
 template <class T>
-inline void AssignStep1D(const size_t step, std::vector<T> &vector,
-                         const size_t ghostCells = 0)
+inline void AssignStep1D(const size_t step, std::vector<T> &vector, const size_t ghostCells = 0)
 {
     std::for_each(vector.begin() + ghostCells, vector.end() - ghostCells,
                   [step](T &value) { value = static_cast<T>(step); });
@@ -33,11 +32,10 @@ template <>
 void AssignStep1D(const size_t step, std::vector<std::complex<float>> &vector,
                   const size_t ghostCells)
 {
-    std::for_each(vector.begin() + ghostCells, vector.end() - ghostCells,
-                  [step](std::complex<float> &value) {
-                      value = std::complex<float>(static_cast<float>(step),
-                                                  static_cast<float>(step));
-                  });
+    std::for_each(
+        vector.begin() + ghostCells, vector.end() - ghostCells, [step](std::complex<float> &value) {
+            value = std::complex<float>(static_cast<float>(step), static_cast<float>(step));
+        });
 }
 
 template <>
@@ -52,9 +50,8 @@ void AssignStep1D(const size_t step, std::vector<std::complex<double>> &vector,
 }
 
 template <class T>
-inline void AssignStep2D(const size_t step, std::vector<T> &vector,
-                         const size_t Nx, const size_t Ny,
-                         const size_t ghostCellsX, const size_t ghostCellsY)
+inline void AssignStep2D(const size_t step, std::vector<T> &vector, const size_t Nx,
+                         const size_t Ny, const size_t ghostCellsX, const size_t ghostCellsY)
 {
     for (size_t j = ghostCellsY; j < Ny + ghostCellsY; ++j)
     {
@@ -69,9 +66,8 @@ inline void AssignStep2D(const size_t step, std::vector<T> &vector,
 }
 
 template <>
-void AssignStep2D(const size_t step, std::vector<std::complex<float>> &vector,
-                  const size_t Nx, const size_t Ny, const size_t ghostCellsX,
-                  const size_t ghostCellsY)
+void AssignStep2D(const size_t step, std::vector<std::complex<float>> &vector, const size_t Nx,
+                  const size_t Ny, const size_t ghostCellsX, const size_t ghostCellsY)
 {
     for (size_t j = ghostCellsY; j < Ny + ghostCellsY; ++j)
     {
@@ -80,16 +76,14 @@ void AssignStep2D(const size_t step, std::vector<std::complex<float>> &vector,
         for (size_t i = ghostCellsX; i < Nx + ghostCellsX; ++i)
         {
             const size_t index = indexJ + i;
-            vector[index] = std::complex<float>(static_cast<float>(step),
-                                                static_cast<float>(step));
+            vector[index] = std::complex<float>(static_cast<float>(step), static_cast<float>(step));
         }
     }
 }
 
 template <>
-void AssignStep2D(const size_t step, std::vector<std::complex<double>> &vector,
-                  const size_t Nx, const size_t Ny, const size_t ghostCellsX,
-                  const size_t ghostCellsY)
+void AssignStep2D(const size_t step, std::vector<std::complex<double>> &vector, const size_t Nx,
+                  const size_t Ny, const size_t ghostCellsX, const size_t ghostCellsY)
 {
     for (size_t j = ghostCellsY; j < Ny + ghostCellsY; ++j)
     {
@@ -98,22 +92,20 @@ void AssignStep2D(const size_t step, std::vector<std::complex<double>> &vector,
         for (size_t i = ghostCellsX; i < Nx + ghostCellsX; ++i)
         {
             const size_t index = indexJ + i;
-            vector[index] = std::complex<double>(static_cast<double>(step),
-                                                 static_cast<double>(step));
+            vector[index] =
+                std::complex<double>(static_cast<double>(step), static_cast<double>(step));
         }
     }
 }
 
 template <class T>
-inline void AssignStep3D(const size_t step, std::vector<T> &vector,
-                         const size_t Nx, const size_t Ny, const size_t Nz,
-                         const size_t ghostCellsX, const size_t ghostCellsY,
-                         const size_t ghostCellsZ)
+inline void AssignStep3D(const size_t step, std::vector<T> &vector, const size_t Nx,
+                         const size_t Ny, const size_t Nz, const size_t ghostCellsX,
+                         const size_t ghostCellsY, const size_t ghostCellsZ)
 {
     for (size_t k = ghostCellsZ; k < Nz + ghostCellsZ; ++k)
     {
-        const size_t indexK =
-            k * (Ny + 2 * ghostCellsY) * (Nx + 2 * ghostCellsX);
+        const size_t indexK = k * (Ny + 2 * ghostCellsY) * (Nx + 2 * ghostCellsX);
 
         for (size_t j = ghostCellsY; j < Ny + ghostCellsY; ++j)
         {
@@ -129,15 +121,13 @@ inline void AssignStep3D(const size_t step, std::vector<T> &vector,
 }
 
 template <>
-void AssignStep3D(const size_t step, std::vector<std::complex<float>> &vector,
-                  const size_t Nx, const size_t Ny, const size_t Nz,
-                  const size_t ghostCellsX, const size_t ghostCellsY,
-                  const size_t ghostCellsZ)
+void AssignStep3D(const size_t step, std::vector<std::complex<float>> &vector, const size_t Nx,
+                  const size_t Ny, const size_t Nz, const size_t ghostCellsX,
+                  const size_t ghostCellsY, const size_t ghostCellsZ)
 {
     for (size_t k = ghostCellsZ; k < Nz + ghostCellsZ; ++k)
     {
-        const size_t indexK =
-            k * (Ny + 2 * ghostCellsY) * (Nx + 2 * ghostCellsX);
+        const size_t indexK = k * (Ny + 2 * ghostCellsY) * (Nx + 2 * ghostCellsX);
 
         for (size_t j = ghostCellsY; j < Ny + ghostCellsY; ++j)
         {
@@ -146,23 +136,21 @@ void AssignStep3D(const size_t step, std::vector<std::complex<float>> &vector,
             for (size_t i = ghostCellsX; i < Nx + ghostCellsX; ++i)
             {
                 const size_t index = indexK + indexJ + i;
-                vector[index] = std::complex<float>(static_cast<float>(step),
-                                                    static_cast<float>(step));
+                vector[index] =
+                    std::complex<float>(static_cast<float>(step), static_cast<float>(step));
             }
         }
     }
 }
 
 template <>
-void AssignStep3D(const size_t step, std::vector<std::complex<double>> &vector,
-                  const size_t Nx, const size_t Ny, const size_t Nz,
-                  const size_t ghostCellsX, const size_t ghostCellsY,
-                  const size_t ghostCellsZ)
+void AssignStep3D(const size_t step, std::vector<std::complex<double>> &vector, const size_t Nx,
+                  const size_t Ny, const size_t Nz, const size_t ghostCellsX,
+                  const size_t ghostCellsY, const size_t ghostCellsZ)
 {
     for (size_t k = ghostCellsZ; k < Nz + ghostCellsZ; ++k)
     {
-        const size_t indexK =
-            k * (Ny + 2 * ghostCellsY) * (Nx + 2 * ghostCellsX);
+        const size_t indexK = k * (Ny + 2 * ghostCellsY) * (Nx + 2 * ghostCellsX);
 
         for (size_t j = ghostCellsY; j < Ny + ghostCellsY; ++j)
         {
@@ -171,8 +159,8 @@ void AssignStep3D(const size_t step, std::vector<std::complex<double>> &vector,
             for (size_t i = ghostCellsX; i < Nx + ghostCellsX; ++i)
             {
                 const size_t index = indexK + indexJ + i;
-                vector[index] = std::complex<double>(static_cast<double>(step),
-                                                     static_cast<double>(step));
+                vector[index] =
+                    std::complex<double>(static_cast<double>(step), static_cast<double>(step));
             }
         }
     }
@@ -186,7 +174,6 @@ MPI_Comm testComm;
 
 void BPSteps1D(const size_t ghostCells)
 {
-    const std::string fname("BPSteps1D_" + std::to_string(ghostCells));
 
     int mpiRank = 0, mpiSize = 1;
     // Number of rows
@@ -198,6 +185,9 @@ void BPSteps1D(const size_t ghostCells)
 #if ADIOS2_USE_MPI
     MPI_Comm_rank(testComm, &mpiRank);
     MPI_Comm_size(testComm, &mpiSize);
+    const std::string fname("BPSteps1D_" + std::to_string(ghostCells) + "_MPI");
+#else
+    const std::string fname("BPSteps1D_" + std::to_string(ghostCells));
 #endif
 
 #if ADIOS2_USE_MPI
@@ -225,10 +215,8 @@ void BPSteps1D(const size_t ghostCells)
         auto var_i64 = io.DefineVariable<int64_t>("i64", shape, start, count);
         auto var_r32 = io.DefineVariable<float>("r32", shape, start, count);
         auto var_r64 = io.DefineVariable<double>("r64", shape, start, count);
-        auto var_cr32 =
-            io.DefineVariable<std::complex<float>>("cr32", shape, start, count);
-        auto var_cr64 = io.DefineVariable<std::complex<double>>("cr64", shape,
-                                                                start, count);
+        auto var_cr32 = io.DefineVariable<std::complex<float>>("cr32", shape, start, count);
+        auto var_cr64 = io.DefineVariable<std::complex<double>>("cr64", shape, start, count);
 
         const adios2::Dims memoryStart = {ghostCells};
         const adios2::Dims memoryCount = {Nx + 2 * ghostCells};
@@ -248,10 +236,8 @@ void BPSteps1D(const size_t ghostCells)
         std::vector<int64_t> dataI64(Nx + 2 * ghostCells, -1);
         std::vector<float> dataR32(Nx + 2 * ghostCells, -1.f);
         std::vector<double> dataR64(Nx + 2 * ghostCells, -1.);
-        std::vector<std::complex<float>> dataCR32(Nx + 2 * ghostCells,
-                                                  {-1.f, -1.f});
-        std::vector<std::complex<double>> dataCR64(Nx + 2 * ghostCells,
-                                                   {-1., -1.});
+        std::vector<std::complex<float>> dataCR32(Nx + 2 * ghostCells, {-1.f, -1.f});
+        std::vector<std::complex<double>> dataCR64(Nx + 2 * ghostCells, {-1., -1.});
 
         adios2::Engine bpWriter = io.Open(fname, adios2::Mode::Write);
 
@@ -372,38 +358,28 @@ void BPSteps1D(const size_t ghostCells)
             EXPECT_EQ(R32.front(), static_cast<float>(step));
             EXPECT_EQ(R64.front(), static_cast<double>(step));
             EXPECT_EQ(CR32.front(),
-                      std::complex<float>(static_cast<float>(step),
-                                          static_cast<float>(step)));
+                      std::complex<float>(static_cast<float>(step), static_cast<float>(step)));
             EXPECT_EQ(CR64.front(),
-                      std::complex<double>(static_cast<double>(step),
-                                           static_cast<double>(step)));
+                      std::complex<double>(static_cast<double>(step), static_cast<double>(step)));
 
-            EXPECT_EQ(std::adjacent_find(I8.begin(), I8.end(),
-                                         std::not_equal_to<int8_t>()),
+            EXPECT_EQ(std::adjacent_find(I8.begin(), I8.end(), std::not_equal_to<int8_t>()),
                       I8.end());
-            EXPECT_EQ(std::adjacent_find(I16.begin(), I16.end(),
-                                         std::not_equal_to<int16_t>()),
+            EXPECT_EQ(std::adjacent_find(I16.begin(), I16.end(), std::not_equal_to<int16_t>()),
                       I16.end());
-            EXPECT_EQ(std::adjacent_find(I32.begin(), I32.end(),
-                                         std::not_equal_to<int32_t>()),
+            EXPECT_EQ(std::adjacent_find(I32.begin(), I32.end(), std::not_equal_to<int32_t>()),
                       I32.end());
-            EXPECT_EQ(std::adjacent_find(I64.begin(), I64.end(),
-                                         std::not_equal_to<int64_t>()),
+            EXPECT_EQ(std::adjacent_find(I64.begin(), I64.end(), std::not_equal_to<int64_t>()),
                       I64.end());
-            EXPECT_EQ(std::adjacent_find(R32.begin(), R32.end(),
-                                         std::not_equal_to<float>()),
+            EXPECT_EQ(std::adjacent_find(R32.begin(), R32.end(), std::not_equal_to<float>()),
                       R32.end());
-            EXPECT_EQ(std::adjacent_find(R64.begin(), R64.end(),
-                                         std::not_equal_to<double>()),
+            EXPECT_EQ(std::adjacent_find(R64.begin(), R64.end(), std::not_equal_to<double>()),
                       R64.end());
-            EXPECT_EQ(
-                std::adjacent_find(CR32.begin(), CR32.end(),
-                                   std::not_equal_to<std::complex<float>>()),
-                CR32.end());
-            EXPECT_EQ(
-                std::adjacent_find(CR64.begin(), CR64.end(),
-                                   std::not_equal_to<std::complex<double>>()),
-                CR64.end());
+            EXPECT_EQ(std::adjacent_find(CR32.begin(), CR32.end(),
+                                         std::not_equal_to<std::complex<float>>()),
+                      CR32.end());
+            EXPECT_EQ(std::adjacent_find(CR64.begin(), CR64.end(),
+                                         std::not_equal_to<std::complex<double>>()),
+                      CR64.end());
         }
 
         bpReader.Close();
@@ -412,7 +388,6 @@ void BPSteps1D(const size_t ghostCells)
 
 void BPSteps2D4x2(const size_t ghostCells)
 {
-    const std::string fname("BPSteps2D4x2_" + std::to_string(ghostCells));
 
     int mpiRank = 0, mpiSize = 1;
     // Number of rows
@@ -428,6 +403,9 @@ void BPSteps2D4x2(const size_t ghostCells)
 #if ADIOS2_USE_MPI
     MPI_Comm_rank(testComm, &mpiRank);
     MPI_Comm_size(testComm, &mpiSize);
+    const std::string fname("BPSteps2D4x2_" + std::to_string(ghostCells) + "_MPI");
+#else
+    const std::string fname("BPSteps2D4x2_" + std::to_string(ghostCells));
 #endif
 
 #if ADIOS2_USE_MPI
@@ -454,14 +432,11 @@ void BPSteps2D4x2(const size_t ghostCells)
         auto var_i64 = io.DefineVariable<int64_t>("i64", shape, start, count);
         auto var_r32 = io.DefineVariable<float>("r32", shape, start, count);
         auto var_r64 = io.DefineVariable<double>("r64", shape, start, count);
-        auto var_cr32 =
-            io.DefineVariable<std::complex<float>>("cr32", shape, start, count);
-        auto var_cr64 = io.DefineVariable<std::complex<double>>("cr64", shape,
-                                                                start, count);
+        auto var_cr32 = io.DefineVariable<std::complex<float>>("cr32", shape, start, count);
+        auto var_cr64 = io.DefineVariable<std::complex<double>>("cr64", shape, start, count);
 
         const adios2::Dims memoryStart = {ghostCellsY, ghostCellsX};
-        const adios2::Dims memoryCount = {Ny + 2 * ghostCellsY,
-                                          Nx + 2 * ghostCellsX};
+        const adios2::Dims memoryCount = {Ny + 2 * ghostCellsY, Nx + 2 * ghostCellsX};
 
         var_i8.SetMemorySelection({memoryStart, memoryCount});
         var_i16.SetMemorySelection({memoryStart, memoryCount});
@@ -611,38 +586,28 @@ void BPSteps2D4x2(const size_t ghostCells)
             EXPECT_EQ(R32.front(), static_cast<float>(step));
             EXPECT_EQ(R64.front(), static_cast<double>(step));
             EXPECT_EQ(CR32.front(),
-                      std::complex<float>(static_cast<float>(step),
-                                          static_cast<float>(step)));
+                      std::complex<float>(static_cast<float>(step), static_cast<float>(step)));
             EXPECT_EQ(CR64.front(),
-                      std::complex<double>(static_cast<double>(step),
-                                           static_cast<double>(step)));
+                      std::complex<double>(static_cast<double>(step), static_cast<double>(step)));
 
-            EXPECT_EQ(std::adjacent_find(I8.begin(), I8.end(),
-                                         std::not_equal_to<int8_t>()),
+            EXPECT_EQ(std::adjacent_find(I8.begin(), I8.end(), std::not_equal_to<int8_t>()),
                       I8.end());
-            EXPECT_EQ(std::adjacent_find(I16.begin(), I16.end(),
-                                         std::not_equal_to<int16_t>()),
+            EXPECT_EQ(std::adjacent_find(I16.begin(), I16.end(), std::not_equal_to<int16_t>()),
                       I16.end());
-            EXPECT_EQ(std::adjacent_find(I32.begin(), I32.end(),
-                                         std::not_equal_to<int32_t>()),
+            EXPECT_EQ(std::adjacent_find(I32.begin(), I32.end(), std::not_equal_to<int32_t>()),
                       I32.end());
-            EXPECT_EQ(std::adjacent_find(I64.begin(), I64.end(),
-                                         std::not_equal_to<int64_t>()),
+            EXPECT_EQ(std::adjacent_find(I64.begin(), I64.end(), std::not_equal_to<int64_t>()),
                       I64.end());
-            EXPECT_EQ(std::adjacent_find(R32.begin(), R32.end(),
-                                         std::not_equal_to<float>()),
+            EXPECT_EQ(std::adjacent_find(R32.begin(), R32.end(), std::not_equal_to<float>()),
                       R32.end());
-            EXPECT_EQ(std::adjacent_find(R64.begin(), R64.end(),
-                                         std::not_equal_to<double>()),
+            EXPECT_EQ(std::adjacent_find(R64.begin(), R64.end(), std::not_equal_to<double>()),
                       R64.end());
-            EXPECT_EQ(
-                std::adjacent_find(CR32.begin(), CR32.end(),
-                                   std::not_equal_to<std::complex<float>>()),
-                CR32.end());
-            EXPECT_EQ(
-                std::adjacent_find(CR64.begin(), CR64.end(),
-                                   std::not_equal_to<std::complex<double>>()),
-                CR64.end());
+            EXPECT_EQ(std::adjacent_find(CR32.begin(), CR32.end(),
+                                         std::not_equal_to<std::complex<float>>()),
+                      CR32.end());
+            EXPECT_EQ(std::adjacent_find(CR64.begin(), CR64.end(),
+                                         std::not_equal_to<std::complex<double>>()),
+                      CR64.end());
         }
 
         bpReader.Close();
@@ -651,7 +616,6 @@ void BPSteps2D4x2(const size_t ghostCells)
 
 void BPSteps3D8x2x4(const size_t ghostCells)
 {
-    const std::string fname("BPSteps3D8x2x4_" + std::to_string(ghostCells));
 
     int mpiRank = 0, mpiSize = 1;
     // Number of rows
@@ -669,6 +633,9 @@ void BPSteps3D8x2x4(const size_t ghostCells)
 #if ADIOS2_USE_MPI
     MPI_Comm_rank(testComm, &mpiRank);
     MPI_Comm_size(testComm, &mpiSize);
+    const std::string fname("BPSteps3D8x2x4_" + std::to_string(ghostCells) + "_MPI");
+#else
+    const std::string fname("BPSteps3D8x2x4_" + std::to_string(ghostCells));
 #endif
 
 #if ADIOS2_USE_MPI
@@ -695,15 +662,12 @@ void BPSteps3D8x2x4(const size_t ghostCells)
         auto var_i64 = io.DefineVariable<int64_t>("i64", shape, start, count);
         auto var_r32 = io.DefineVariable<float>("r32", shape, start, count);
         auto var_r64 = io.DefineVariable<double>("r64", shape, start, count);
-        auto var_cr32 =
-            io.DefineVariable<std::complex<float>>("cr32", shape, start, count);
-        auto var_cr64 = io.DefineVariable<std::complex<double>>("cr64", shape,
-                                                                start, count);
+        auto var_cr32 = io.DefineVariable<std::complex<float>>("cr32", shape, start, count);
+        auto var_cr64 = io.DefineVariable<std::complex<double>>("cr64", shape, start, count);
 
-        const adios2::Dims memoryStart = {ghostCellsZ, ghostCellsY,
-                                          ghostCellsX};
-        const adios2::Dims memoryCount = {
-            Nz + 2 * ghostCellsZ, Ny + 2 * ghostCellsY, Nx + 2 * ghostCellsX};
+        const adios2::Dims memoryStart = {ghostCellsZ, ghostCellsY, ghostCellsX};
+        const adios2::Dims memoryCount = {Nz + 2 * ghostCellsZ, Ny + 2 * ghostCellsY,
+                                          Nx + 2 * ghostCellsX};
 
         var_i8.SetMemorySelection({memoryStart, memoryCount});
         var_i16.SetMemorySelection({memoryStart, memoryCount});
@@ -714,8 +678,8 @@ void BPSteps3D8x2x4(const size_t ghostCells)
         var_cr32.SetMemorySelection({memoryStart, memoryCount});
         var_cr64.SetMemorySelection({memoryStart, memoryCount});
 
-        const size_t dataSize = (Nz + 2 * ghostCellsZ) *
-                                (Ny + 2 * ghostCellsY) * (Nx + 2 * ghostCellsX);
+        const size_t dataSize =
+            (Nz + 2 * ghostCellsZ) * (Ny + 2 * ghostCellsY) * (Nx + 2 * ghostCellsX);
         std::vector<int8_t> dataI8(dataSize, -1);
         std::vector<int16_t> dataI16(dataSize, -1);
         std::vector<int32_t> dataI32(dataSize, -1);
@@ -729,22 +693,14 @@ void BPSteps3D8x2x4(const size_t ghostCells)
 
         for (size_t i = 0; i < NSteps; ++i)
         {
-            AssignStep3D(i, dataI8, Nx, Ny, Nz, ghostCellsX, ghostCellsY,
-                         ghostCellsZ);
-            AssignStep3D(i, dataI16, Nx, Ny, Nz, ghostCellsX, ghostCellsY,
-                         ghostCellsZ);
-            AssignStep3D(i, dataI32, Nx, Ny, Nz, ghostCellsX, ghostCellsY,
-                         ghostCellsZ);
-            AssignStep3D(i, dataI64, Nx, Ny, Nz, ghostCellsX, ghostCellsY,
-                         ghostCellsZ);
-            AssignStep3D(i, dataR32, Nx, Ny, Nz, ghostCellsX, ghostCellsY,
-                         ghostCellsZ);
-            AssignStep3D(i, dataR64, Nx, Ny, Nz, ghostCellsX, ghostCellsY,
-                         ghostCellsZ);
-            AssignStep3D(i, dataCR32, Nx, Ny, Nz, ghostCellsX, ghostCellsY,
-                         ghostCellsZ);
-            AssignStep3D(i, dataCR64, Nx, Ny, Nz, ghostCellsX, ghostCellsY,
-                         ghostCellsZ);
+            AssignStep3D(i, dataI8, Nx, Ny, Nz, ghostCellsX, ghostCellsY, ghostCellsZ);
+            AssignStep3D(i, dataI16, Nx, Ny, Nz, ghostCellsX, ghostCellsY, ghostCellsZ);
+            AssignStep3D(i, dataI32, Nx, Ny, Nz, ghostCellsX, ghostCellsY, ghostCellsZ);
+            AssignStep3D(i, dataI64, Nx, Ny, Nz, ghostCellsX, ghostCellsY, ghostCellsZ);
+            AssignStep3D(i, dataR32, Nx, Ny, Nz, ghostCellsX, ghostCellsY, ghostCellsZ);
+            AssignStep3D(i, dataR64, Nx, Ny, Nz, ghostCellsX, ghostCellsY, ghostCellsZ);
+            AssignStep3D(i, dataCR32, Nx, Ny, Nz, ghostCellsX, ghostCellsY, ghostCellsZ);
+            AssignStep3D(i, dataCR64, Nx, Ny, Nz, ghostCellsX, ghostCellsY, ghostCellsZ);
 
             bpWriter.BeginStep();
             bpWriter.Put(var_i8, dataI8.data());
@@ -895,38 +851,28 @@ void BPSteps3D8x2x4(const size_t ghostCells)
             EXPECT_EQ(R32.front(), static_cast<float>(step));
             EXPECT_EQ(R64.front(), static_cast<double>(step));
             EXPECT_EQ(CR32.front(),
-                      std::complex<float>(static_cast<float>(step),
-                                          static_cast<float>(step)));
+                      std::complex<float>(static_cast<float>(step), static_cast<float>(step)));
             EXPECT_EQ(CR64.front(),
-                      std::complex<double>(static_cast<double>(step),
-                                           static_cast<double>(step)));
+                      std::complex<double>(static_cast<double>(step), static_cast<double>(step)));
 
-            EXPECT_EQ(std::adjacent_find(I8.begin(), I8.end(),
-                                         std::not_equal_to<int8_t>()),
+            EXPECT_EQ(std::adjacent_find(I8.begin(), I8.end(), std::not_equal_to<int8_t>()),
                       I8.end());
-            EXPECT_EQ(std::adjacent_find(I16.begin(), I16.end(),
-                                         std::not_equal_to<int16_t>()),
+            EXPECT_EQ(std::adjacent_find(I16.begin(), I16.end(), std::not_equal_to<int16_t>()),
                       I16.end());
-            EXPECT_EQ(std::adjacent_find(I32.begin(), I32.end(),
-                                         std::not_equal_to<int32_t>()),
+            EXPECT_EQ(std::adjacent_find(I32.begin(), I32.end(), std::not_equal_to<int32_t>()),
                       I32.end());
-            EXPECT_EQ(std::adjacent_find(I64.begin(), I64.end(),
-                                         std::not_equal_to<int64_t>()),
+            EXPECT_EQ(std::adjacent_find(I64.begin(), I64.end(), std::not_equal_to<int64_t>()),
                       I64.end());
-            EXPECT_EQ(std::adjacent_find(R32.begin(), R32.end(),
-                                         std::not_equal_to<float>()),
+            EXPECT_EQ(std::adjacent_find(R32.begin(), R32.end(), std::not_equal_to<float>()),
                       R32.end());
-            EXPECT_EQ(std::adjacent_find(R64.begin(), R64.end(),
-                                         std::not_equal_to<double>()),
+            EXPECT_EQ(std::adjacent_find(R64.begin(), R64.end(), std::not_equal_to<double>()),
                       R64.end());
-            EXPECT_EQ(
-                std::adjacent_find(CR32.begin(), CR32.end(),
-                                   std::not_equal_to<std::complex<float>>()),
-                CR32.end());
-            EXPECT_EQ(
-                std::adjacent_find(CR64.begin(), CR64.end(),
-                                   std::not_equal_to<std::complex<double>>()),
-                CR64.end());
+            EXPECT_EQ(std::adjacent_find(CR32.begin(), CR32.end(),
+                                         std::not_equal_to<std::complex<float>>()),
+                      CR32.end());
+            EXPECT_EQ(std::adjacent_find(CR64.begin(), CR64.end(),
+                                         std::not_equal_to<std::complex<double>>()),
+                      CR64.end());
         }
 
         bpReader.Close();
@@ -941,23 +887,13 @@ public:
     virtual void TearDown() {}
 };
 
-TEST_P(BPWriteMemSelReadVector, BPMemorySelectionSteps1D)
-{
-    BPSteps1D(GetParam());
-}
+TEST_P(BPWriteMemSelReadVector, BPMemorySelectionSteps1D) { BPSteps1D(GetParam()); }
 
-TEST_P(BPWriteMemSelReadVector, BPMemorySelectionSteps2D4x2)
-{
-    BPSteps2D4x2(GetParam());
-}
+TEST_P(BPWriteMemSelReadVector, BPMemorySelectionSteps2D4x2) { BPSteps2D4x2(GetParam()); }
 
-TEST_P(BPWriteMemSelReadVector, BPMemorySelectionSteps3D4x2x8)
-{
-    BPSteps3D8x2x4(GetParam());
-}
+TEST_P(BPWriteMemSelReadVector, BPMemorySelectionSteps3D4x2x8) { BPSteps3D8x2x4(GetParam()); }
 
-INSTANTIATE_TEST_SUITE_P(ghostCells, BPWriteMemSelReadVector,
-                         ::testing::Values(1));
+INSTANTIATE_TEST_SUITE_P(ghostCells, BPWriteMemSelReadVector, ::testing::Values(1));
 
 int main(int argc, char **argv)
 {
