@@ -7,6 +7,10 @@
 extern "C" {
 #endif
 
+#ifdef _MSC_VER
+#define FD_SETSIZE 1024
+#include <winsock2.h>
+#endif
 typedef struct _avail_period {
     struct timeval offset;
     struct timeval duration;
