@@ -2,6 +2,7 @@
 #include "cod.h"
 #define assert(EX) ((EX) ? (void)0 : (fprintf(stderr, "\"%s\" failed, file %s, line %d\n", #EX, __FILE__, __LINE__), exit(1)))
 #include <stdio.h>
+#include <stdint.h>
 char code_string[] = "{return sizeof(int);}";
 char code_string2[] = "{return sizeof(int*);}";
 char code_string3[] = "{   int j;      return sizeof j;}";
@@ -19,12 +20,12 @@ main()
 	cod_exec_context ec;
 
 	cod_code gen_code;
-	int (*func)();
+	int (*func)(cod_exec_context);
 
 	cod_add_param("ec", "cod_exec_context", 0, context);
 	gen_code = cod_code_gen(code_blocks[test], context);
 	ec = cod_create_exec_context(gen_code);
-	func = (int(*)())gen_code->func;
+	func = (int(*)(cod_exec_context))gen_code->func;
 	ret = (func)(ec);
 	if (ret != results[test]) {
 	    printf("bad test %d, ret was %d\n", test, ret);
