@@ -4,16 +4,24 @@
 #include "assert.h"
 #include "atl.h"
 #include "ffs.h"
-#include "fm_internal.h"
-#include "ffs_internal.h"
-#include "strings.h"
+#include "string.h"
 #include "stdio.h"
 #include "stdlib.h"
+#ifndef _MSC_VER
 #include "unistd.h"
+#include <arpa/inet.h>
+#else
+#include <winsock.h>
+#include <io.h>
+#endif
 #include "errno.h"
 #include "string.h"
-#include <arpa/inet.h>
-
+#include "sys/types.h"
+#include <fcntl.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include "fm_internal.h"
+#include "ffs_internal.h"
 #include "io_interface.h"
 
 typedef struct _CDLLnode {
@@ -218,8 +226,7 @@ static FFSRecordType next_record_type(FFSFile ffsfile);
 static void
 update_fpos(FFSFile f)
 {
-    int fd = (int)(long)f->file_id;
-    f->fpos = lseek(fd, 0, SEEK_CUR);
+    f->fpos = ffs_file_lseek_func(f->file_id, 0, SEEK_CUR);
 }
 
 static void
@@ -400,20 +407,20 @@ open_FFSfile(const char *path, const char *flags)
     parse_flags(flags, &allow_input, &allow_output, &raw, &index);
 
     if (allow_input && allow_output) {
-	file = ffs_file_open_func(path, "a", NULL, NULL);
+	file = (FFSFile) (ffs_file_open_func)(path, "a", NULL, NULL);
 	if (file == (void*)0) {
 	    /* if open for append failed, try creating it */
-	    file = ffs_file_open_func(path, "w", NULL, NULL);
+	    file = (FFSFile)(ffs_file_open_func)(path, "w", NULL, NULL);
 	}
     } else if (allow_input) {
-	file = ffs_file_open_func(path, "r", NULL, NULL);
+	file = (FFSFile)(ffs_file_open_func)(path, "r", NULL, NULL);
     } else {
-	file = ffs_file_open_func(path, "w", NULL, NULL);
+	file = (FFSFile)(ffs_file_open_func)(path, "w", NULL, NULL);
     }
 
     if (file == NULL) {
 	char msg[128];
-	(void) sprintf(msg, "open_FFSfile failed for %s :", path);
+	(void) snprintf(msg, sizeof(msg), "open_FFSfile failed for %s :", path);
 	perror(msg);
 	return NULL;
     }
@@ -434,15 +441,8 @@ FMContext_of_file(FFSFile f)
 }
 
 extern void
-set_interface_FFSFile(f, write_func, read_func, writev_func, readv_func,
-		     max_iov, close_func)
-FFSFile f;
-IOinterface_func write_func;
-IOinterface_func read_func;
-IOinterface_funcv writev_func;
-IOinterface_funcv readv_func;
-int max_iov;
-IOinterface_close close_func;
+set_interface_FFSFile(FFSFile f, IOinterface_func write_func, IOinterface_func read_func, IOinterface_funcv writev_func,
+                      IOinterface_funcv readv_func, int max_iov, IOinterface_close close_func)
 {
     f->write_func = write_func;
     f->read_func = read_func;
@@ -481,10 +481,9 @@ static void
 init_write_index_block(FFSFile f)
 {
     int data_index_start = 0;
-    int fd = (int)(long)f->file_id;
     off_t end_of_index;
     if (f->read_index == NULL) { /* if not append */
-	end_of_index = lseek(fd, INDEX_BLOCK_SIZE, SEEK_CUR);
+	end_of_index = ffs_file_lseek_func(f->file_id, INDEX_BLOCK_SIZE, SEEK_CUR);
 	if (f->cur_index) {
 	    data_index_start = f->cur_index->write_info.data_index_end;
 	} else {
@@ -512,30 +511,29 @@ static void output_index_end(FFSFile f);
 static void
 dump_index_block(FFSFile f)
 {
-    int fd = (int)(long)f->file_id;
-    off_t end = lseek(fd, 0, SEEK_CUR);
+    off_t end = ffs_file_lseek_func(f->file_id, 0, SEEK_CUR);
     int ret;
 
-    int size =  f->cur_index->write_info.index_block_size;
+    size_t size =  f->cur_index->write_info.index_block_size;
     unsigned char *index_base = f->cur_index->write_info.index_block;
 
     output_index_end(f);
     f->cur_index->write_info.data_index_end = f->data_count-1;
-    lseek(fd, f->cur_index->write_info.base_file_pos, SEEK_SET);
+    ffs_file_lseek_func(f->file_id, f->cur_index->write_info.base_file_pos, SEEK_SET);
     /*
      * next_data indicator is a 2 4-byte chunks in network byte order.
      * In the first chunk, 
      *    the top byte is 0x4, next three are length of the index block.
      */
-    *((int*)index_base) = htonl((0x4<<24) | size);
-    *((int*)(index_base+4)) = htonl(end);  /* link to next index */
-    *((int*)(index_base+8)) = htonl(f->cur_index->write_info.data_index_start); /* data_index_start); */
-    *((int*)(index_base+12)) = htonl(f->cur_index->write_info.data_index_end); /* data_index_end); */
+    *((int*)index_base) = (int) htonl((0x4<<24) | (long)size);
+    *((int*)(index_base + 4)) = (int)htonl(end);  /* link to next index */
+    *((int*)(index_base+8)) = (int)htonl(f->cur_index->write_info.data_index_start); /* data_index_start); */
+    *((int*)(index_base+12)) = (int)htonl(f->cur_index->write_info.data_index_end); /* data_index_end); */
     ret = f->write_func(f->file_id, index_base, size, NULL, NULL);
     if (ret != size) {
 	printf("Index write failed errno %d\n", errno);
     }
-    lseek(fd, end, SEEK_SET);
+    ffs_file_lseek_func(f->file_id, end, SEEK_SET);
     init_write_index_block(f);
 }
 
@@ -797,7 +795,7 @@ write_comment_FFSfile(FFSFile f, const char *comment)
 {
     struct iovec vec[2];
 
-    int byte_size = strlen(comment) + 1;
+    size_t byte_size = strlen(comment) + 1;
     int indicator;
     /*
      * next_comment indicator is a 4-byte chunk in network byte order.
@@ -1057,11 +1055,10 @@ FFSread_index(FFSFile ffsfile)
     char *index_data;
     FFSIndexItem index_item;
     off_t index_fpos;
-    int index_size;
-    int fd = (int)(long)ffsfile->file_id;
-    int currentPos = lseek(fd, (size_t)0, SEEK_CUR);
-    int end = lseek(fd, (size_t)0, SEEK_END);
-    lseek(fd, currentPos, SEEK_SET);   // seek back to original spot
+    size_t index_size;
+    int currentPos = ffs_file_lseek_func(ffsfile->file_id, (size_t)0, SEEK_CUR);
+    int end = ffs_file_lseek_func(ffsfile->file_id, (size_t)0, SEEK_END);
+    ffs_file_lseek_func(ffsfile->file_id, currentPos, SEEK_SET);   // seek back to original spot
 
     if (ffsfile->read_ahead == FALSE) {
 	(void) next_record_type(ffsfile);
@@ -1150,8 +1147,7 @@ FFSdump_index(FFSIndexItem index_item)
 
 extern
 FFSTypeHandle
-FFSnext_type_handle(ffsfile)
-FFSFile ffsfile;
+FFSnext_type_handle(FFSFile ffsfile)
 {
     if (ffsfile->status != OpenForRead)
 	return NULL;
@@ -1169,7 +1165,7 @@ FFSFile ffsfile;
     return ffsfile->next_data_handle;
 }
 
-extern long
+extern size_t
 FFSfile_next_decode_length(FFSFile iofile)
 {
     FFSContext context = iofile->c;
@@ -1181,8 +1177,7 @@ FFSfile_next_decode_length(FFSFile iofile)
 
 extern
 char *
-FFSread_comment(ffsfile)
-FFSFile ffsfile;
+FFSread_comment(FFSFile ffsfile)
 {
     if (ffsfile->status != OpenForRead)
 	return NULL;
@@ -1208,7 +1203,6 @@ FFSFile ffsfile;
 static int
 FFSset_fpos(FFSFile file,  off_t fpos)
 {
-    int fd = (int)(long)file->file_id;
     /* dangerous to set FPOS if not indexed, but we'll allow it */
     if (file->file_org == Indexed) {
 	/* 
@@ -1224,7 +1218,7 @@ FFSset_fpos(FFSFile file,  off_t fpos)
 	last_element = &file->index_tail->elements[last_element_index];
 	while(fpos > last_element->fpos) {
 	    /* don't skip forward past index blocks without reading them */
-	    if (lseek(fd, file->index_tail->next_index_offset, SEEK_SET) == -1)
+	    if (ffs_file_lseek_func(file->file_id, file->index_tail->next_index_offset, SEEK_SET) == -1)
 		return 0;
 	    file->read_ahead = FALSE;
 	    (void) FFSread_index(file);
@@ -1233,7 +1227,7 @@ FFSset_fpos(FFSFile file,  off_t fpos)
 	    last_element = &file->index_tail->elements[last_element_index];
 	}
     }
-    if (lseek(fd, fpos, SEEK_SET) == -1) return 0;
+    if (ffs_file_lseek_func(file->file_id, fpos, SEEK_SET) == -1) return 0;
     file->read_ahead = FALSE;
     return 1;
 }
@@ -1245,7 +1239,6 @@ FFSset_fpos(FFSFile file,  off_t fpos)
 extern int
 FFSseek(FFSFile file, int data_item)
 {
-    int fd = (int)(long)file->file_id;
     struct _FFSIndexItem *index;
     off_t fpos;
     int index_item;
@@ -1265,7 +1258,7 @@ FFSseek(FFSFile file, int data_item)
     while (data_item > file->index_tail->last_data_count &&
            file->index_tail != prev_index_tail) {
 	/* don't skip forward past index blocks without reading them */
-	if (lseek(fd, file->index_tail->next_index_offset, SEEK_SET) == -1)
+	if (ffs_file_lseek_func(file->file_id, file->index_tail->next_index_offset, SEEK_SET) == -1)
 	    return 0;
     	file->read_ahead = FALSE;
         prev_index_tail = file->index_tail;
@@ -1299,9 +1292,7 @@ FFSseek(FFSFile file, int data_item)
     
 static
 int
-get_AtomicInt(file, file_int_ptr)
-FFSFile file;
-FILE_INT *file_int_ptr;
+get_AtomicInt(FFSFile file, FILE_INT *file_int_ptr)
 {
 #if SIZEOF_INT == 4
     int tmp_value;
@@ -1318,11 +1309,10 @@ FILE_INT *file_int_ptr;
 static void
 read_all_index_and_formats(FFSFile file)
 {
-    int fd = (int)(long)file->file_id;
     off_t fpos = 1;
-    int currentPos = lseek(fd, (size_t)0, SEEK_CUR);
-    int end = lseek(fd, (size_t)0, SEEK_END);
-    lseek(fd, currentPos, SEEK_SET);   // seek back to original spot
+    int currentPos = ffs_file_lseek_func(file->file_id, (size_t)0, SEEK_CUR);
+    int end = ffs_file_lseek_func(file->file_id, (size_t)0, SEEK_END);
+    ffs_file_lseek_func(file->file_id, currentPos, SEEK_SET);   // seek back to original spot
 
     if (!file->index_head)
         FFSread_index(file);
@@ -1340,7 +1330,7 @@ read_all_index_and_formats(FFSFile file)
 	for (i = 0; i < file->index_tail->elem_count; i++) {
 	    if (file->index_tail->elements[i].type == FFSformat) {
 		fpos = file->index_tail->elements[i].fpos;
-		if (lseek(fd, fpos, SEEK_SET) == -1)
+		if (ffs_file_lseek_func(file->file_id, fpos, SEEK_SET) == -1)
 		    return;
 		(void) FFSread_format(file);
 	    }
@@ -1348,13 +1338,13 @@ read_all_index_and_formats(FFSFile file)
 	/* skip to next index block */
 	fpos = file->index_tail->next_index_offset;
 	if (fpos != end) {
-	    if (lseek(fd, fpos, SEEK_SET) == -1)
+	    if (ffs_file_lseek_func(file->file_id, fpos, SEEK_SET) == -1)
 		return;
 	    FFSread_index(file);
 	}
     }
-    lseek(fd, 0, SEEK_END);
-    file->fpos = lseek(fd, 0, SEEK_CUR);
+    ffs_file_lseek_func(file->file_id, 0, SEEK_END);
+    file->fpos = ffs_file_lseek_func(file->file_id, 0, SEEK_CUR);
 }
 
 static void
@@ -1382,14 +1372,12 @@ convert_last_index_block(FFSFile ffsfile)
     }
     ffsfile->cur_index->write_info.data_index_start =  htonl(*((int*)(index_data+8)));;
     ffsfile->data_count = read_index->last_data_count + 1;
-    int fd = (int)(long)ffsfile->file_id;
-    if (lseek(fd, 0, SEEK_END) == -1)
+    if (ffs_file_lseek_func(ffsfile->file_id, 0, SEEK_END) == -1)
 	return;
 }
 
 FFSRecordType
-FFSnext_record_type(ffsfile)
-FFSFile ffsfile;
+FFSnext_record_type(FFSFile ffsfile)
 {
     FFSRecordType next = next_record_type(ffsfile);
     while ((next & ffsfile->visible_items_bitmap) != next) {
@@ -1408,8 +1396,7 @@ FFSset_visible(FFSFile ffsfile, int bitmap)
 
 static
 FFSRecordType
-next_record_type(ffsfile)
-FFSFile ffsfile;
+next_record_type(FFSFile ffsfile)
 {
     FILE_INT indicator_chunk = 0;
  restart:
@@ -1479,11 +1466,10 @@ FFSFile ffsfile;
                 if (!ffsfile->next_actual_handle && ffsfile->index_head) {
 
                     struct _FFSIndexItem *index = NULL;
-                    int fd = (int)(long)ffsfile->file_id;
-                    off_t fpos_bak = lseek(fd, 0, SEEK_CUR);
+                    off_t fpos_bak = ffs_file_lseek_func(ffsfile->file_id, 0, SEEK_CUR);
 		    int fid_len = ffsfile->next_fid_len;
 		    char tmp_fid_storage[64];
-		    int tmp_data_len;
+		    size_t tmp_data_len;
 		    int done = 0;
 		    assert(sizeof(tmp_fid_storage) > fid_len);
 		    /* store away the format ID we've read */
@@ -1501,10 +1487,10 @@ FFSFile ffsfile;
 				!(memcmp(elem->format_id,
 					 tmp_buf, ffsfile->next_fid_len))) {
 
-				if (lseek(fd, elem->fpos, SEEK_SET) != -1) {
+				if (ffs_file_lseek_func(ffsfile->file_id, elem->fpos, SEEK_SET) != -1) {
 				    ffsfile->read_ahead = FALSE;
 				    FFSread_format(ffsfile);
-				    lseek(fd, fpos_bak, SEEK_SET);
+				    ffs_file_lseek_func(ffsfile->file_id, fpos_bak, SEEK_SET);
 				    ffsfile->read_ahead = TRUE;
 				    ffsfile->next_record_type = FFSdata;
 				    /* tmp_buf might have changed */
@@ -1545,7 +1531,7 @@ FFSFile ffsfile;
 		if ((ffsfile->next_data_handle == NULL) &&
                     (!ffsfile->raw_flag)) {
 		    /* no target for this format, discard */
-		    int more = ffsfile->next_data_len - ffsfile->next_fid_len;
+		    size_t more = ffsfile->next_data_len - ffsfile->next_fid_len;
 		    if (ffsfile->read_func(ffsfile->file_id, tmp_buf +
                                            ffsfile->next_fid_len, more, NULL,
                                            NULL) != more) {
@@ -1574,7 +1560,7 @@ FFSFile ffsfile;
 		ffsfile->next_record_type = FFSindex;
 		ffsfile->next_data_len = indicator_chunk & 0xffffff;
 /*		if (!ffsfile->expose_index) {
-		    lseek((int)(long)ffsfile->file_id, INDEX_BLOCK_SIZE-4, SEEK_CUR);
+		    ffs_file_lseek_func((int)(intptr_t)ffsfile->file_id, INDEX_BLOCK_SIZE-4, SEEK_CUR);
 		    ffsfile->read_ahead = FALSE;
 		    return next_record_type(ffsfile);
 		    }*/
@@ -1589,7 +1575,7 @@ FFSFile ffsfile;
     return ffsfile->next_record_type;
 }
 
-extern long
+extern size_t
 FFSnext_data_length(FFSFile file)
 {
     if (file->status != OpenForRead)
@@ -1608,7 +1594,7 @@ extern int
 FFSread(FFSFile file, void *dest)
 {
     int header_size;
-    int read_size;
+    size_t read_size;
     char *tmp_buf;
 
     if (file->status != OpenForRead)
@@ -1701,7 +1687,7 @@ FFSread_raw(FFSFile file, void *dest, int buffer_size, FFSTypeHandle *fp)
 {
     FFSTypeHandle f;
     int header_size;
-    int read_size;
+    size_t read_size;
 
     if (file->status != OpenForRead)
 	return 0;
@@ -1732,7 +1718,7 @@ FFSread_raw_header(FFSFile file, void *dest, int buffer_size, FFSTypeHandle *fp)
 {
     FFSTypeHandle f;
     int header_size;
-    int read_size;
+    size_t read_size;
 
     if (file->status != OpenForRead)
 	return 0;
@@ -1767,7 +1753,7 @@ extern int
 FFSread_to_buffer(FFSFile file, FFSBuffer b,  void **dest)
 {
     int header_size;
-    int read_size;
+    size_t read_size;
     char *tmp_buf;
 
     if (file->status != OpenForRead)
