@@ -35,9 +35,7 @@ file_checksum(char *filename)
 }
 
 int
-main(argc,argv)
-int argc;
-char **argv;
+main(int argc, char **argv)
 {
     unsigned int base_sum, sum;
     int i, found_match = 0;
